#! /usr/bin/env python
"""This script is intended to give me an idea of current performance with various drawing strategies"""
from OpenGL.GL import *
from OpenGL.GLU import *
from OpenGL.GLUT import *
from OpenGL.arrays import vbo
import cProfile, time, os
PROFILER = cProfile.Profile()

import numpy

def dump( ):
    def newfile( base ):
        new = base 
        count = 0
        while os.path.isfile( new ):
            new = '%s-%s%s'%( 
                os.path.splitext(base)[0], 
                count,
                os.path.splitext(base)[1] 
            )
            count += 1
        return new
    PROFILER.dump_stats( newfile( 'performance.profile' ) )


def init_vbo( size = 1000000 ):
    """Create VBO with vertices of count size"""
    a = numpy.zeros( (size,3), dtype='d')
    xes = numpy.arange(-5,5,float(10)/size, dtype='d' )
    a[:len(xes),0] = xes
    a[:len(xes),1] = numpy.sin( xes )
    a[:len(xes),2] = numpy.cos( xes )
    v = a
    v = vbo.VBO( a )
    v.bind()
    glEnableClientState(GL_VERTEX_ARRAY);
    glEnable( GL_LIGHTING )
    glEnable( GL_LIGHT0 )
    glDisable( GL_CULL_FACE )
    glColor3f( 1.0,1.0,1.0)
    glNormal3f( 0.0, 0.0, 1.0 )
    return v 

def draw_with_array( a , count):
    glDrawArrays( GL_TRIANGLES, 0, (count) )
    glFlush()
    glutSwapBuffers()

def init():
    glMatrixMode (GL_PROJECTION)
    glLoadIdentity()
    gluPerspective(40.0, 300/300, 1.0, 20.0)
    glMatrixMode(GL_MODELVIEW)
    glLoadIdentity()
    gluLookAt(
        20,0,0, # eyepoint
        0,0,0, # center-of-view
        0,1,0, # up-vector
    )
    glClearColor( 0,0,.25, 0 )
    glClear( GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT )

def display( ):
    init()
    repeat = range(100)
    for count in [(2**i) for i in range(8,19)]:
        v = init_vbo( count )
        def x( ):
            t1 = time.time()
            for i in repeat:
                glVertexPointer(  3, GL_DOUBLE, 0, v )
                draw_with_array( v, count )
            t2 = time.time()
            print 'Count: %s Total Time for %s iterations: %s  MTri/s: %s'%(
                count, len(repeat), t2-t1, (count*len(repeat)/(t2-t1)/1000000)
            )
        PROFILER.runcall( x )
    dump()
    import sys
    sys.exit(1)
    print 'should not get here'

if __name__ == "__main__":
    import sys
    newArgv = glutInit(sys.argv)
    glutInitDisplayMode( GLUT_DOUBLE | GLUT_RGB )
    glutInitWindowSize(250, 250)
    glutInitWindowPosition(100, 100)
    window = glutCreateWindow("hello")
    glutDisplayFunc(display)
    glutMainLoop()


'''OpenGL extension ARB.depth_texture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_depth_texture'
_DEPRECATED = False
GL_DEPTH_COMPONENT16_ARB = constant.Constant( 'GL_DEPTH_COMPONENT16_ARB', 0x81A5 )
GL_DEPTH_COMPONENT24_ARB = constant.Constant( 'GL_DEPTH_COMPONENT24_ARB', 0x81A6 )
GL_DEPTH_COMPONENT32_ARB = constant.Constant( 'GL_DEPTH_COMPONENT32_ARB', 0x81A7 )
GL_TEXTURE_DEPTH_SIZE_ARB = constant.Constant( 'GL_TEXTURE_DEPTH_SIZE_ARB', 0x884A )
GL_DEPTH_TEXTURE_MODE_ARB = constant.Constant( 'GL_DEPTH_TEXTURE_MODE_ARB', 0x884B )


def glInitDepthTextureARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.color_matrix

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.color_matrix to provide a more 
Python-friendly API
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.EXT.color_matrix import *
### END AUTOGENERATED SECTION


'''OpenGL extension SGIX.ycrcba

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_ycrcba'
_DEPRECATED = False
GL_YCRCB_SGIX = constant.Constant( 'GL_YCRCB_SGIX', 0x8318 )
GL_YCRCBA_SGIX = constant.Constant( 'GL_YCRCBA_SGIX', 0x8319 )


def glInitYcrcbaSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.instanced_arrays

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_instanced_arrays'
_DEPRECATED = False
GL_VERTEX_ATTRIB_ARRAY_DIVISOR_ARB = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_DIVISOR_ARB', 0x88FE )
glVertexAttribDivisorARB = platform.createExtensionFunction( 
'glVertexAttribDivisorARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,),
doc='glVertexAttribDivisorARB(GLuint(index), GLuint(divisor)) -> None',
argNames=('index','divisor',),
deprecated=_DEPRECATED,
)


def glInitInstancedArraysARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.geometry_program4

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_geometry_program4'
_DEPRECATED = False
GL_LINES_ADJACENCY_EXT = constant.Constant( 'GL_LINES_ADJACENCY_EXT', 0xA )
GL_LINE_STRIP_ADJACENCY_EXT = constant.Constant( 'GL_LINE_STRIP_ADJACENCY_EXT', 0xB )
GL_TRIANGLES_ADJACENCY_EXT = constant.Constant( 'GL_TRIANGLES_ADJACENCY_EXT', 0xC )
GL_TRIANGLE_STRIP_ADJACENCY_EXT = constant.Constant( 'GL_TRIANGLE_STRIP_ADJACENCY_EXT', 0xD )
GL_GEOMETRY_PROGRAM_NV = constant.Constant( 'GL_GEOMETRY_PROGRAM_NV', 0x8C26 )
GL_MAX_PROGRAM_OUTPUT_VERTICES_NV = constant.Constant( 'GL_MAX_PROGRAM_OUTPUT_VERTICES_NV', 0x8C27 )
GL_MAX_PROGRAM_TOTAL_OUTPUT_COMPONENTS_NV = constant.Constant( 'GL_MAX_PROGRAM_TOTAL_OUTPUT_COMPONENTS_NV', 0x8C28 )
GL_GEOMETRY_VERTICES_OUT_EXT = constant.Constant( 'GL_GEOMETRY_VERTICES_OUT_EXT', 0x8DDA )
GL_GEOMETRY_INPUT_TYPE_EXT = constant.Constant( 'GL_GEOMETRY_INPUT_TYPE_EXT', 0x8DDB )
GL_GEOMETRY_OUTPUT_TYPE_EXT = constant.Constant( 'GL_GEOMETRY_OUTPUT_TYPE_EXT', 0x8DDC )
GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_EXT = constant.Constant( 'GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_EXT', 0x8C29 )
glget.addGLGetConstant( GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_EXT, (1,) )
GL_FRAMEBUFFER_ATTACHMENT_LAYERED_EXT = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_LAYERED_EXT', 0x8DA7 )
GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_EXT = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_EXT', 0x8DA8 )
GL_FRAMEBUFFER_INCOMPLETE_LAYER_COUNT_EXT = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_LAYER_COUNT_EXT', 0x8DA9 )
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER_EXT = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER_EXT', 0x8CD4 )
GL_PROGRAM_POINT_SIZE_EXT = constant.Constant( 'GL_PROGRAM_POINT_SIZE_EXT', 0x8642 )
glget.addGLGetConstant( GL_PROGRAM_POINT_SIZE_EXT, (1,) )
glProgramVertexLimitNV = platform.createExtensionFunction( 
'glProgramVertexLimitNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,),
doc='glProgramVertexLimitNV(GLenum(target), GLint(limit)) -> None',
argNames=('target','limit',),
deprecated=_DEPRECATED,
)

glFramebufferTextureEXT = platform.createExtensionFunction( 
'glFramebufferTextureEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,),
doc='glFramebufferTextureEXT(GLenum(target), GLenum(attachment), GLuint(texture), GLint(level)) -> None',
argNames=('target','attachment','texture','level',),
deprecated=_DEPRECATED,
)

glFramebufferTextureLayerEXT = platform.createExtensionFunction( 
'glFramebufferTextureLayerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,constants.GLint,),
doc='glFramebufferTextureLayerEXT(GLenum(target), GLenum(attachment), GLuint(texture), GLint(level), GLint(layer)) -> None',
argNames=('target','attachment','texture','level','layer',),
deprecated=_DEPRECATED,
)

glFramebufferTextureFaceEXT = platform.createExtensionFunction( 
'glFramebufferTextureFaceEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,constants.GLenum,),
doc='glFramebufferTextureFaceEXT(GLenum(target), GLenum(attachment), GLuint(texture), GLint(level), GLenum(face)) -> None',
argNames=('target','attachment','texture','level','face',),
deprecated=_DEPRECATED,
)


def glInitGeometryProgram4NV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.multitexture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_multitexture'
_DEPRECATED = False
GL_TEXTURE0_ARB = constant.Constant( 'GL_TEXTURE0_ARB', 0x84C0 )
GL_TEXTURE1_ARB = constant.Constant( 'GL_TEXTURE1_ARB', 0x84C1 )
GL_TEXTURE2_ARB = constant.Constant( 'GL_TEXTURE2_ARB', 0x84C2 )
GL_TEXTURE3_ARB = constant.Constant( 'GL_TEXTURE3_ARB', 0x84C3 )
GL_TEXTURE4_ARB = constant.Constant( 'GL_TEXTURE4_ARB', 0x84C4 )
GL_TEXTURE5_ARB = constant.Constant( 'GL_TEXTURE5_ARB', 0x84C5 )
GL_TEXTURE6_ARB = constant.Constant( 'GL_TEXTURE6_ARB', 0x84C6 )
GL_TEXTURE7_ARB = constant.Constant( 'GL_TEXTURE7_ARB', 0x84C7 )
GL_TEXTURE8_ARB = constant.Constant( 'GL_TEXTURE8_ARB', 0x84C8 )
GL_TEXTURE9_ARB = constant.Constant( 'GL_TEXTURE9_ARB', 0x84C9 )
GL_TEXTURE10_ARB = constant.Constant( 'GL_TEXTURE10_ARB', 0x84CA )
GL_TEXTURE11_ARB = constant.Constant( 'GL_TEXTURE11_ARB', 0x84CB )
GL_TEXTURE12_ARB = constant.Constant( 'GL_TEXTURE12_ARB', 0x84CC )
GL_TEXTURE13_ARB = constant.Constant( 'GL_TEXTURE13_ARB', 0x84CD )
GL_TEXTURE14_ARB = constant.Constant( 'GL_TEXTURE14_ARB', 0x84CE )
GL_TEXTURE15_ARB = constant.Constant( 'GL_TEXTURE15_ARB', 0x84CF )
GL_TEXTURE16_ARB = constant.Constant( 'GL_TEXTURE16_ARB', 0x84D0 )
GL_TEXTURE17_ARB = constant.Constant( 'GL_TEXTURE17_ARB', 0x84D1 )
GL_TEXTURE18_ARB = constant.Constant( 'GL_TEXTURE18_ARB', 0x84D2 )
GL_TEXTURE19_ARB = constant.Constant( 'GL_TEXTURE19_ARB', 0x84D3 )
GL_TEXTURE20_ARB = constant.Constant( 'GL_TEXTURE20_ARB', 0x84D4 )
GL_TEXTURE21_ARB = constant.Constant( 'GL_TEXTURE21_ARB', 0x84D5 )
GL_TEXTURE22_ARB = constant.Constant( 'GL_TEXTURE22_ARB', 0x84D6 )
GL_TEXTURE23_ARB = constant.Constant( 'GL_TEXTURE23_ARB', 0x84D7 )
GL_TEXTURE24_ARB = constant.Constant( 'GL_TEXTURE24_ARB', 0x84D8 )
GL_TEXTURE25_ARB = constant.Constant( 'GL_TEXTURE25_ARB', 0x84D9 )
GL_TEXTURE26_ARB = constant.Constant( 'GL_TEXTURE26_ARB', 0x84DA )
GL_TEXTURE27_ARB = constant.Constant( 'GL_TEXTURE27_ARB', 0x84DB )
GL_TEXTURE28_ARB = constant.Constant( 'GL_TEXTURE28_ARB', 0x84DC )
GL_TEXTURE29_ARB = constant.Constant( 'GL_TEXTURE29_ARB', 0x84DD )
GL_TEXTURE30_ARB = constant.Constant( 'GL_TEXTURE30_ARB', 0x84DE )
GL_TEXTURE31_ARB = constant.Constant( 'GL_TEXTURE31_ARB', 0x84DF )
GL_ACTIVE_TEXTURE_ARB = constant.Constant( 'GL_ACTIVE_TEXTURE_ARB', 0x84E0 )
GL_CLIENT_ACTIVE_TEXTURE_ARB = constant.Constant( 'GL_CLIENT_ACTIVE_TEXTURE_ARB', 0x84E1 )
GL_MAX_TEXTURE_UNITS_ARB = constant.Constant( 'GL_MAX_TEXTURE_UNITS_ARB', 0x84E2 )
glActiveTextureARB = platform.createExtensionFunction( 
'glActiveTextureARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glActiveTextureARB(GLenum(texture)) -> None',
argNames=('texture',),
deprecated=_DEPRECATED,
)

glClientActiveTextureARB = platform.createExtensionFunction( 
'glClientActiveTextureARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glClientActiveTextureARB(GLenum(texture)) -> None',
argNames=('texture',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1dARB = platform.createExtensionFunction( 
'glMultiTexCoord1dARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,),
doc='glMultiTexCoord1dARB(GLenum(target), GLdouble(s)) -> None',
argNames=('target','s',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1dvARB = platform.createExtensionFunction( 
'glMultiTexCoord1dvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMultiTexCoord1dvARB(GLenum(target), GLdoubleArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1fARB = platform.createExtensionFunction( 
'glMultiTexCoord1fARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,),
doc='glMultiTexCoord1fARB(GLenum(target), GLfloat(s)) -> None',
argNames=('target','s',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1fvARB = platform.createExtensionFunction( 
'glMultiTexCoord1fvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMultiTexCoord1fvARB(GLenum(target), GLfloatArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1iARB = platform.createExtensionFunction( 
'glMultiTexCoord1iARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,),
doc='glMultiTexCoord1iARB(GLenum(target), GLint(s)) -> None',
argNames=('target','s',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1ivARB = platform.createExtensionFunction( 
'glMultiTexCoord1ivARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glMultiTexCoord1ivARB(GLenum(target), GLintArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1sARB = platform.createExtensionFunction( 
'glMultiTexCoord1sARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLshort,),
doc='glMultiTexCoord1sARB(GLenum(target), GLshort(s)) -> None',
argNames=('target','s',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1svARB = platform.createExtensionFunction( 
'glMultiTexCoord1svARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLshortArray,),
doc='glMultiTexCoord1svARB(GLenum(target), GLshortArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2dARB = platform.createExtensionFunction( 
'glMultiTexCoord2dARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,),
doc='glMultiTexCoord2dARB(GLenum(target), GLdouble(s), GLdouble(t)) -> None',
argNames=('target','s','t',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2dvARB = platform.createExtensionFunction( 
'glMultiTexCoord2dvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMultiTexCoord2dvARB(GLenum(target), GLdoubleArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2fARB = platform.createExtensionFunction( 
'glMultiTexCoord2fARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,),
doc='glMultiTexCoord2fARB(GLenum(target), GLfloat(s), GLfloat(t)) -> None',
argNames=('target','s','t',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2fvARB = platform.createExtensionFunction( 
'glMultiTexCoord2fvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMultiTexCoord2fvARB(GLenum(target), GLfloatArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2iARB = platform.createExtensionFunction( 
'glMultiTexCoord2iARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,),
doc='glMultiTexCoord2iARB(GLenum(target), GLint(s), GLint(t)) -> None',
argNames=('target','s','t',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2ivARB = platform.createExtensionFunction( 
'glMultiTexCoord2ivARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glMultiTexCoord2ivARB(GLenum(target), GLintArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2sARB = platform.createExtensionFunction( 
'glMultiTexCoord2sARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLshort,constants.GLshort,),
doc='glMultiTexCoord2sARB(GLenum(target), GLshort(s), GLshort(t)) -> None',
argNames=('target','s','t',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2svARB = platform.createExtensionFunction( 
'glMultiTexCoord2svARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLshortArray,),
doc='glMultiTexCoord2svARB(GLenum(target), GLshortArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3dARB = platform.createExtensionFunction( 
'glMultiTexCoord3dARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glMultiTexCoord3dARB(GLenum(target), GLdouble(s), GLdouble(t), GLdouble(r)) -> None',
argNames=('target','s','t','r',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3dvARB = platform.createExtensionFunction( 
'glMultiTexCoord3dvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMultiTexCoord3dvARB(GLenum(target), GLdoubleArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3fARB = platform.createExtensionFunction( 
'glMultiTexCoord3fARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glMultiTexCoord3fARB(GLenum(target), GLfloat(s), GLfloat(t), GLfloat(r)) -> None',
argNames=('target','s','t','r',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3fvARB = platform.createExtensionFunction( 
'glMultiTexCoord3fvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMultiTexCoord3fvARB(GLenum(target), GLfloatArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3iARB = platform.createExtensionFunction( 
'glMultiTexCoord3iARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,),
doc='glMultiTexCoord3iARB(GLenum(target), GLint(s), GLint(t), GLint(r)) -> None',
argNames=('target','s','t','r',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3ivARB = platform.createExtensionFunction( 
'glMultiTexCoord3ivARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glMultiTexCoord3ivARB(GLenum(target), GLintArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3sARB = platform.createExtensionFunction( 
'glMultiTexCoord3sARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glMultiTexCoord3sARB(GLenum(target), GLshort(s), GLshort(t), GLshort(r)) -> None',
argNames=('target','s','t','r',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3svARB = platform.createExtensionFunction( 
'glMultiTexCoord3svARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLshortArray,),
doc='glMultiTexCoord3svARB(GLenum(target), GLshortArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4dARB = platform.createExtensionFunction( 
'glMultiTexCoord4dARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glMultiTexCoord4dARB(GLenum(target), GLdouble(s), GLdouble(t), GLdouble(r), GLdouble(q)) -> None',
argNames=('target','s','t','r','q',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4dvARB = platform.createExtensionFunction( 
'glMultiTexCoord4dvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glMultiTexCoord4dvARB(GLenum(target), GLdoubleArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4fARB = platform.createExtensionFunction( 
'glMultiTexCoord4fARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glMultiTexCoord4fARB(GLenum(target), GLfloat(s), GLfloat(t), GLfloat(r), GLfloat(q)) -> None',
argNames=('target','s','t','r','q',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4fvARB = platform.createExtensionFunction( 
'glMultiTexCoord4fvARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glMultiTexCoord4fvARB(GLenum(target), GLfloatArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4iARB = platform.createExtensionFunction( 
'glMultiTexCoord4iARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glMultiTexCoord4iARB(GLenum(target), GLint(s), GLint(t), GLint(r), GLint(q)) -> None',
argNames=('target','s','t','r','q',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4ivARB = platform.createExtensionFunction( 
'glMultiTexCoord4ivARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glMultiTexCoord4ivARB(GLenum(target), GLintArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4sARB = platform.createExtensionFunction( 
'glMultiTexCoord4sARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLshort,constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glMultiTexCoord4sARB(GLenum(target), GLshort(s), GLshort(t), GLshort(r), GLshort(q)) -> None',
argNames=('target','s','t','r','q',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4svARB = platform.createExtensionFunction( 
'glMultiTexCoord4svARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLshortArray,),
doc='glMultiTexCoord4svARB(GLenum(target), GLshortArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)


def glInitMultitextureARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ATI.vertex_streams

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_vertex_streams'
_DEPRECATED = False
GL_MAX_VERTEX_STREAMS_ATI = constant.Constant( 'GL_MAX_VERTEX_STREAMS_ATI', 0x876B )
glget.addGLGetConstant( GL_MAX_VERTEX_STREAMS_ATI, (1,) )
GL_VERTEX_STREAM0_ATI = constant.Constant( 'GL_VERTEX_STREAM0_ATI', 0x876C )
GL_VERTEX_STREAM1_ATI = constant.Constant( 'GL_VERTEX_STREAM1_ATI', 0x876D )
GL_VERTEX_STREAM2_ATI = constant.Constant( 'GL_VERTEX_STREAM2_ATI', 0x876E )
GL_VERTEX_STREAM3_ATI = constant.Constant( 'GL_VERTEX_STREAM3_ATI', 0x876F )
GL_VERTEX_STREAM4_ATI = constant.Constant( 'GL_VERTEX_STREAM4_ATI', 0x8770 )
GL_VERTEX_STREAM5_ATI = constant.Constant( 'GL_VERTEX_STREAM5_ATI', 0x8771 )
GL_VERTEX_STREAM6_ATI = constant.Constant( 'GL_VERTEX_STREAM6_ATI', 0x8772 )
GL_VERTEX_STREAM7_ATI = constant.Constant( 'GL_VERTEX_STREAM7_ATI', 0x8773 )
GL_VERTEX_SOURCE_ATI = constant.Constant( 'GL_VERTEX_SOURCE_ATI', 0x8774 )
glVertexStream1sATI = platform.createExtensionFunction( 
'glVertexStream1sATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLshort,),
doc='glVertexStream1sATI(GLenum(stream), GLshort(x)) -> None',
argNames=('stream','x',),
deprecated=_DEPRECATED,
)

glVertexStream1svATI = platform.createExtensionFunction( 
'glVertexStream1svATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLshortArray,),
doc='glVertexStream1svATI(GLenum(stream), GLshortArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream1iATI = platform.createExtensionFunction( 
'glVertexStream1iATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,),
doc='glVertexStream1iATI(GLenum(stream), GLint(x)) -> None',
argNames=('stream','x',),
deprecated=_DEPRECATED,
)

glVertexStream1ivATI = platform.createExtensionFunction( 
'glVertexStream1ivATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glVertexStream1ivATI(GLenum(stream), GLintArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream1fATI = platform.createExtensionFunction( 
'glVertexStream1fATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,),
doc='glVertexStream1fATI(GLenum(stream), GLfloat(x)) -> None',
argNames=('stream','x',),
deprecated=_DEPRECATED,
)

glVertexStream1fvATI = platform.createExtensionFunction( 
'glVertexStream1fvATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glVertexStream1fvATI(GLenum(stream), GLfloatArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream1dATI = platform.createExtensionFunction( 
'glVertexStream1dATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,),
doc='glVertexStream1dATI(GLenum(stream), GLdouble(x)) -> None',
argNames=('stream','x',),
deprecated=_DEPRECATED,
)

glVertexStream1dvATI = platform.createExtensionFunction( 
'glVertexStream1dvATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glVertexStream1dvATI(GLenum(stream), GLdoubleArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream2sATI = platform.createExtensionFunction( 
'glVertexStream2sATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLshort,constants.GLshort,),
doc='glVertexStream2sATI(GLenum(stream), GLshort(x), GLshort(y)) -> None',
argNames=('stream','x','y',),
deprecated=_DEPRECATED,
)

glVertexStream2svATI = platform.createExtensionFunction( 
'glVertexStream2svATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLshortArray,),
doc='glVertexStream2svATI(GLenum(stream), GLshortArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream2iATI = platform.createExtensionFunction( 
'glVertexStream2iATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,),
doc='glVertexStream2iATI(GLenum(stream), GLint(x), GLint(y)) -> None',
argNames=('stream','x','y',),
deprecated=_DEPRECATED,
)

glVertexStream2ivATI = platform.createExtensionFunction( 
'glVertexStream2ivATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glVertexStream2ivATI(GLenum(stream), GLintArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream2fATI = platform.createExtensionFunction( 
'glVertexStream2fATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,),
doc='glVertexStream2fATI(GLenum(stream), GLfloat(x), GLfloat(y)) -> None',
argNames=('stream','x','y',),
deprecated=_DEPRECATED,
)

glVertexStream2fvATI = platform.createExtensionFunction( 
'glVertexStream2fvATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glVertexStream2fvATI(GLenum(stream), GLfloatArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream2dATI = platform.createExtensionFunction( 
'glVertexStream2dATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,),
doc='glVertexStream2dATI(GLenum(stream), GLdouble(x), GLdouble(y)) -> None',
argNames=('stream','x','y',),
deprecated=_DEPRECATED,
)

glVertexStream2dvATI = platform.createExtensionFunction( 
'glVertexStream2dvATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glVertexStream2dvATI(GLenum(stream), GLdoubleArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream3sATI = platform.createExtensionFunction( 
'glVertexStream3sATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glVertexStream3sATI(GLenum(stream), GLshort(x), GLshort(y), GLshort(z)) -> None',
argNames=('stream','x','y','z',),
deprecated=_DEPRECATED,
)

glVertexStream3svATI = platform.createExtensionFunction( 
'glVertexStream3svATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLshortArray,),
doc='glVertexStream3svATI(GLenum(stream), GLshortArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream3iATI = platform.createExtensionFunction( 
'glVertexStream3iATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,),
doc='glVertexStream3iATI(GLenum(stream), GLint(x), GLint(y), GLint(z)) -> None',
argNames=('stream','x','y','z',),
deprecated=_DEPRECATED,
)

glVertexStream3ivATI = platform.createExtensionFunction( 
'glVertexStream3ivATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glVertexStream3ivATI(GLenum(stream), GLintArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream3fATI = platform.createExtensionFunction( 
'glVertexStream3fATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glVertexStream3fATI(GLenum(stream), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('stream','x','y','z',),
deprecated=_DEPRECATED,
)

glVertexStream3fvATI = platform.createExtensionFunction( 
'glVertexStream3fvATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glVertexStream3fvATI(GLenum(stream), GLfloatArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream3dATI = platform.createExtensionFunction( 
'glVertexStream3dATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glVertexStream3dATI(GLenum(stream), GLdouble(x), GLdouble(y), GLdouble(z)) -> None',
argNames=('stream','x','y','z',),
deprecated=_DEPRECATED,
)

glVertexStream3dvATI = platform.createExtensionFunction( 
'glVertexStream3dvATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glVertexStream3dvATI(GLenum(stream), GLdoubleArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream4sATI = platform.createExtensionFunction( 
'glVertexStream4sATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLshort,constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glVertexStream4sATI(GLenum(stream), GLshort(x), GLshort(y), GLshort(z), GLshort(w)) -> None',
argNames=('stream','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexStream4svATI = platform.createExtensionFunction( 
'glVertexStream4svATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLshortArray,),
doc='glVertexStream4svATI(GLenum(stream), GLshortArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream4iATI = platform.createExtensionFunction( 
'glVertexStream4iATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glVertexStream4iATI(GLenum(stream), GLint(x), GLint(y), GLint(z), GLint(w)) -> None',
argNames=('stream','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexStream4ivATI = platform.createExtensionFunction( 
'glVertexStream4ivATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glVertexStream4ivATI(GLenum(stream), GLintArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream4fATI = platform.createExtensionFunction( 
'glVertexStream4fATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glVertexStream4fATI(GLenum(stream), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w)) -> None',
argNames=('stream','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexStream4fvATI = platform.createExtensionFunction( 
'glVertexStream4fvATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glVertexStream4fvATI(GLenum(stream), GLfloatArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glVertexStream4dATI = platform.createExtensionFunction( 
'glVertexStream4dATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glVertexStream4dATI(GLenum(stream), GLdouble(x), GLdouble(y), GLdouble(z), GLdouble(w)) -> None',
argNames=('stream','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexStream4dvATI = platform.createExtensionFunction( 
'glVertexStream4dvATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glVertexStream4dvATI(GLenum(stream), GLdoubleArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glNormalStream3bATI = platform.createExtensionFunction( 
'glNormalStream3bATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLbyte,constants.GLbyte,constants.GLbyte,),
doc='glNormalStream3bATI(GLenum(stream), GLbyte(nx), GLbyte(ny), GLbyte(nz)) -> None',
argNames=('stream','nx','ny','nz',),
deprecated=_DEPRECATED,
)

glNormalStream3bvATI = platform.createExtensionFunction( 
'glNormalStream3bvATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLbyteArray,),
doc='glNormalStream3bvATI(GLenum(stream), GLbyteArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glNormalStream3sATI = platform.createExtensionFunction( 
'glNormalStream3sATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glNormalStream3sATI(GLenum(stream), GLshort(nx), GLshort(ny), GLshort(nz)) -> None',
argNames=('stream','nx','ny','nz',),
deprecated=_DEPRECATED,
)

glNormalStream3svATI = platform.createExtensionFunction( 
'glNormalStream3svATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLshortArray,),
doc='glNormalStream3svATI(GLenum(stream), GLshortArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glNormalStream3iATI = platform.createExtensionFunction( 
'glNormalStream3iATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,),
doc='glNormalStream3iATI(GLenum(stream), GLint(nx), GLint(ny), GLint(nz)) -> None',
argNames=('stream','nx','ny','nz',),
deprecated=_DEPRECATED,
)

glNormalStream3ivATI = platform.createExtensionFunction( 
'glNormalStream3ivATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glNormalStream3ivATI(GLenum(stream), GLintArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glNormalStream3fATI = platform.createExtensionFunction( 
'glNormalStream3fATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glNormalStream3fATI(GLenum(stream), GLfloat(nx), GLfloat(ny), GLfloat(nz)) -> None',
argNames=('stream','nx','ny','nz',),
deprecated=_DEPRECATED,
)

glNormalStream3fvATI = platform.createExtensionFunction( 
'glNormalStream3fvATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glNormalStream3fvATI(GLenum(stream), GLfloatArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glNormalStream3dATI = platform.createExtensionFunction( 
'glNormalStream3dATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glNormalStream3dATI(GLenum(stream), GLdouble(nx), GLdouble(ny), GLdouble(nz)) -> None',
argNames=('stream','nx','ny','nz',),
deprecated=_DEPRECATED,
)

glNormalStream3dvATI = platform.createExtensionFunction( 
'glNormalStream3dvATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLdoubleArray,),
doc='glNormalStream3dvATI(GLenum(stream), GLdoubleArray(coords)) -> None',
argNames=('stream','coords',),
deprecated=_DEPRECATED,
)

glClientActiveVertexStreamATI = platform.createExtensionFunction( 
'glClientActiveVertexStreamATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glClientActiveVertexStreamATI(GLenum(stream)) -> None',
argNames=('stream',),
deprecated=_DEPRECATED,
)

glVertexBlendEnviATI = platform.createExtensionFunction( 
'glVertexBlendEnviATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,),
doc='glVertexBlendEnviATI(GLenum(pname), GLint(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)

glVertexBlendEnvfATI = platform.createExtensionFunction( 
'glVertexBlendEnvfATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,),
doc='glVertexBlendEnvfATI(GLenum(pname), GLfloat(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)


def glInitVertexStreamsATI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.bindable_uniform

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_bindable_uniform'
_DEPRECATED = False
GL_MAX_VERTEX_BINDABLE_UNIFORMS_EXT = constant.Constant( 'GL_MAX_VERTEX_BINDABLE_UNIFORMS_EXT', 0x8DE2 )
glget.addGLGetConstant( GL_MAX_VERTEX_BINDABLE_UNIFORMS_EXT, (1,) )
GL_MAX_FRAGMENT_BINDABLE_UNIFORMS_EXT = constant.Constant( 'GL_MAX_FRAGMENT_BINDABLE_UNIFORMS_EXT', 0x8DE3 )
glget.addGLGetConstant( GL_MAX_FRAGMENT_BINDABLE_UNIFORMS_EXT, (1,) )
GL_MAX_GEOMETRY_BINDABLE_UNIFORMS_EXT = constant.Constant( 'GL_MAX_GEOMETRY_BINDABLE_UNIFORMS_EXT', 0x8DE4 )
glget.addGLGetConstant( GL_MAX_GEOMETRY_BINDABLE_UNIFORMS_EXT, (1,) )
GL_MAX_BINDABLE_UNIFORM_SIZE_EXT = constant.Constant( 'GL_MAX_BINDABLE_UNIFORM_SIZE_EXT', 0x8DED )
glget.addGLGetConstant( GL_MAX_BINDABLE_UNIFORM_SIZE_EXT, (1,) )
GL_UNIFORM_BUFFER_EXT = constant.Constant( 'GL_UNIFORM_BUFFER_EXT', 0x8DEE )
GL_UNIFORM_BUFFER_BINDING_EXT = constant.Constant( 'GL_UNIFORM_BUFFER_BINDING_EXT', 0x8DEF )
glget.addGLGetConstant( GL_UNIFORM_BUFFER_BINDING_EXT, (1,) )
glUniformBufferEXT = platform.createExtensionFunction( 
'glUniformBufferEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLuint,),
doc='glUniformBufferEXT(GLuint(program), GLint(location), GLuint(buffer)) -> None',
argNames=('program','location','buffer',),
deprecated=_DEPRECATED,
)

glGetUniformBufferSizeEXT = platform.createExtensionFunction( 
'glGetUniformBufferSizeEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLint, 
argTypes=(constants.GLuint,constants.GLint,),
doc='glGetUniformBufferSizeEXT(GLuint(program), GLint(location)) -> constants.GLint',
argNames=('program','location',),
deprecated=_DEPRECATED,
)

glGetUniformOffsetEXT = platform.createExtensionFunction( 
'glGetUniformOffsetEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLintptr, 
argTypes=(constants.GLuint,constants.GLint,),
doc='glGetUniformOffsetEXT(GLuint(program), GLint(location)) -> constants.GLintptr',
argNames=('program','location',),
deprecated=_DEPRECATED,
)


def glInitBindableUniformEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



"""GLX (x-windows)-specific platform features"""
import ctypes, ctypes.util
from OpenGL.platform import baseplatform, ctypesloader

assert hasattr( ctypes, 'RTLD_GLOBAL' ), """Old ctypes without ability to load .so for global resolution: Get ctypes CVS branch_1_0, not CVS HEAD or released versions!"""


class GLXPlatform( baseplatform.BasePlatform ):
    """Posix (Linux, FreeBSD, etceteras) implementation for PyOpenGL"""
    # On Linux (and, I assume, most GLX platforms, we have to load 
    # GL and GLU with the "global" flag to allow GLUT to resolve its
    # references to GL/GLU functions).
    try:
        GL = OpenGL = ctypesloader.loadLibrary(
            ctypes.cdll,
            'GL', 
            mode=ctypes.RTLD_GLOBAL 
        )
    except OSError, err:
        raise ImportError("Unable to load OpenGL library", *err.args)
    try:
        GLU = ctypesloader.loadLibrary(
            ctypes.cdll,
            'GLU',
            mode=ctypes.RTLD_GLOBAL 
        )
    except OSError, err:
        GLU = None
    # glut shouldn't need to be global, but just in case a dependent library makes
    # the same assumption GLUT does...
    try:
        GLUT = ctypesloader.loadLibrary(
            ctypes.cdll,
            'glut', 
            mode=ctypes.RTLD_GLOBAL 
        )
    except OSError, err:
        GLUT = None
    # GLX doesn't seem to have its own loadable module?
    GLX = GL
    glXGetProcAddressARB = GL.glXGetProcAddressARB
    glXGetProcAddressARB.restype = ctypes.c_void_p
    getExtensionProcedure = staticmethod( glXGetProcAddressARB )
    try:
        GLE = ctypesloader.loadLibrary(
            ctypes.cdll,
            'gle', 
            mode=ctypes.RTLD_GLOBAL 
        )
    except OSError, err:
        GLE = None

    DEFAULT_FUNCTION_TYPE = staticmethod( ctypes.CFUNCTYPE )

    # This loads the GLX functions from the GL .so, not sure if that's
    # really kosher...
    GetCurrentContext = CurrentContextIsValid = staticmethod(
        GL.glXGetCurrentContext
    )


    def getGLUTFontPointer( self, constant ):
        """Platform specific function to retrieve a GLUT font pointer
        
        GLUTAPI void *glutBitmap9By15;
        #define GLUT_BITMAP_9_BY_15		(&glutBitmap9By15)
        
        Key here is that we want the addressof the pointer in the DLL,
        not the pointer in the DLL.  That is, our pointer is to the 
        pointer defined in the DLL, we don't want the *value* stored in
        that pointer.
        """
        name = [ x.title() for x in constant.split( '_' )[1:] ]
        internal = 'glut' + "".join( [x.title() for x in name] )
        pointer = ctypes.c_void_p.in_dll( self.GLUT, internal )
        return ctypes.c_void_p(ctypes.addressof(pointer))
    
    safeGetError = staticmethod( OpenGL.glGetError )



# BEGIN GENERATED CONTENT (do not edit below this line)

# This content is generated by gengl.py.
# Wrapper for /usr/include/GL/glx.h
from OpenGL import platform, constant
from ctypes import *
c_void = None


# H (/usr/include/GL/glx.h:26)
GLX_VERSION_1_1 = constant.Constant( 'GLX_VERSION_1_1', 1 )
GLX_VERSION_1_2 = constant.Constant( 'GLX_VERSION_1_2', 1 )
GLX_VERSION_1_3 = constant.Constant( 'GLX_VERSION_1_3', 1 )
GLX_VERSION_1_4 = constant.Constant( 'GLX_VERSION_1_4', 1 )
GLX_USE_GL = constant.Constant( 'GLX_USE_GL', 1 )
GLX_BUFFER_SIZE = constant.Constant( 'GLX_BUFFER_SIZE', 2 )
GLX_LEVEL = constant.Constant( 'GLX_LEVEL', 3 )
GLX_RGBA = constant.Constant( 'GLX_RGBA', 4 )
GLX_DOUBLEBUFFER = constant.Constant( 'GLX_DOUBLEBUFFER', 5 )
GLX_STEREO = constant.Constant( 'GLX_STEREO', 6 )
GLX_AUX_BUFFERS = constant.Constant( 'GLX_AUX_BUFFERS', 7 )
GLX_RED_SIZE = constant.Constant( 'GLX_RED_SIZE', 8 )
GLX_GREEN_SIZE = constant.Constant( 'GLX_GREEN_SIZE', 9 )
GLX_BLUE_SIZE = constant.Constant( 'GLX_BLUE_SIZE', 10 )
GLX_ALPHA_SIZE = constant.Constant( 'GLX_ALPHA_SIZE', 11 )
GLX_DEPTH_SIZE = constant.Constant( 'GLX_DEPTH_SIZE', 12 )
GLX_STENCIL_SIZE = constant.Constant( 'GLX_STENCIL_SIZE', 13 )
GLX_ACCUM_RED_SIZE = constant.Constant( 'GLX_ACCUM_RED_SIZE', 14 )
GLX_ACCUM_GREEN_SIZE = constant.Constant( 'GLX_ACCUM_GREEN_SIZE', 15 )
GLX_ACCUM_BLUE_SIZE = constant.Constant( 'GLX_ACCUM_BLUE_SIZE', 16 )
GLX_ACCUM_ALPHA_SIZE = constant.Constant( 'GLX_ACCUM_ALPHA_SIZE', 17 )
GLX_BAD_SCREEN = constant.Constant( 'GLX_BAD_SCREEN', 1 )
GLX_BAD_ATTRIBUTE = constant.Constant( 'GLX_BAD_ATTRIBUTE', 2 )
GLX_NO_EXTENSION = constant.Constant( 'GLX_NO_EXTENSION', 3 )
GLX_BAD_VISUAL = constant.Constant( 'GLX_BAD_VISUAL', 4 )
GLX_BAD_CONTEXT = constant.Constant( 'GLX_BAD_CONTEXT', 5 )
GLX_BAD_VALUE = constant.Constant( 'GLX_BAD_VALUE', 6 )
GLX_BAD_ENUM = constant.Constant( 'GLX_BAD_ENUM', 7 )
GLX_VENDOR = constant.Constant( 'GLX_VENDOR', 1 )
GLX_VERSION = constant.Constant( 'GLX_VERSION', 2 )
GLX_EXTENSIONS = constant.Constant( 'GLX_EXTENSIONS', 3 )
GLX_CONFIG_CAVEAT = constant.Constant( 'GLX_CONFIG_CAVEAT', 32 )
GLX_DONT_CARE = constant.Constant( 'GLX_DONT_CARE', 4294967295L )
GLX_X_VISUAL_TYPE = constant.Constant( 'GLX_X_VISUAL_TYPE', 34 )
GLX_TRANSPARENT_TYPE = constant.Constant( 'GLX_TRANSPARENT_TYPE', 35 )
GLX_TRANSPARENT_INDEX_VALUE = constant.Constant( 'GLX_TRANSPARENT_INDEX_VALUE', 36 )
GLX_TRANSPARENT_RED_VALUE = constant.Constant( 'GLX_TRANSPARENT_RED_VALUE', 37 )
GLX_TRANSPARENT_GREEN_VALUE = constant.Constant( 'GLX_TRANSPARENT_GREEN_VALUE', 38 )
GLX_TRANSPARENT_BLUE_VALUE = constant.Constant( 'GLX_TRANSPARENT_BLUE_VALUE', 39 )
GLX_TRANSPARENT_ALPHA_VALUE = constant.Constant( 'GLX_TRANSPARENT_ALPHA_VALUE', 40 )
GLX_WINDOW_BIT = constant.Constant( 'GLX_WINDOW_BIT', 1 )
GLX_PIXMAP_BIT = constant.Constant( 'GLX_PIXMAP_BIT', 2 )
GLX_PBUFFER_BIT = constant.Constant( 'GLX_PBUFFER_BIT', 4 )
GLX_AUX_BUFFERS_BIT = constant.Constant( 'GLX_AUX_BUFFERS_BIT', 16 )
GLX_FRONT_LEFT_BUFFER_BIT = constant.Constant( 'GLX_FRONT_LEFT_BUFFER_BIT', 1 )
GLX_FRONT_RIGHT_BUFFER_BIT = constant.Constant( 'GLX_FRONT_RIGHT_BUFFER_BIT', 2 )
GLX_BACK_LEFT_BUFFER_BIT = constant.Constant( 'GLX_BACK_LEFT_BUFFER_BIT', 4 )
GLX_BACK_RIGHT_BUFFER_BIT = constant.Constant( 'GLX_BACK_RIGHT_BUFFER_BIT', 8 )
GLX_DEPTH_BUFFER_BIT = constant.Constant( 'GLX_DEPTH_BUFFER_BIT', 32 )
GLX_STENCIL_BUFFER_BIT = constant.Constant( 'GLX_STENCIL_BUFFER_BIT', 64 )
GLX_ACCUM_BUFFER_BIT = constant.Constant( 'GLX_ACCUM_BUFFER_BIT', 128 )
GLX_NONE = constant.Constant( 'GLX_NONE', 32768 )
GLX_SLOW_CONFIG = constant.Constant( 'GLX_SLOW_CONFIG', 32769 )
GLX_TRUE_COLOR = constant.Constant( 'GLX_TRUE_COLOR', 32770 )
GLX_DIRECT_COLOR = constant.Constant( 'GLX_DIRECT_COLOR', 32771 )
GLX_PSEUDO_COLOR = constant.Constant( 'GLX_PSEUDO_COLOR', 32772 )
GLX_STATIC_COLOR = constant.Constant( 'GLX_STATIC_COLOR', 32773 )
GLX_GRAY_SCALE = constant.Constant( 'GLX_GRAY_SCALE', 32774 )
GLX_STATIC_GRAY = constant.Constant( 'GLX_STATIC_GRAY', 32775 )
GLX_TRANSPARENT_RGB = constant.Constant( 'GLX_TRANSPARENT_RGB', 32776 )
GLX_TRANSPARENT_INDEX = constant.Constant( 'GLX_TRANSPARENT_INDEX', 32777 )
GLX_VISUAL_ID = constant.Constant( 'GLX_VISUAL_ID', 32779 )
GLX_SCREEN = constant.Constant( 'GLX_SCREEN', 32780 )
GLX_NON_CONFORMANT_CONFIG = constant.Constant( 'GLX_NON_CONFORMANT_CONFIG', 32781 )
GLX_DRAWABLE_TYPE = constant.Constant( 'GLX_DRAWABLE_TYPE', 32784 )
GLX_RENDER_TYPE = constant.Constant( 'GLX_RENDER_TYPE', 32785 )
GLX_X_RENDERABLE = constant.Constant( 'GLX_X_RENDERABLE', 32786 )
GLX_FBCONFIG_ID = constant.Constant( 'GLX_FBCONFIG_ID', 32787 )
GLX_RGBA_TYPE = constant.Constant( 'GLX_RGBA_TYPE', 32788 )
GLX_COLOR_INDEX_TYPE = constant.Constant( 'GLX_COLOR_INDEX_TYPE', 32789 )
GLX_MAX_PBUFFER_WIDTH = constant.Constant( 'GLX_MAX_PBUFFER_WIDTH', 32790 )
GLX_MAX_PBUFFER_HEIGHT = constant.Constant( 'GLX_MAX_PBUFFER_HEIGHT', 32791 )
GLX_MAX_PBUFFER_PIXELS = constant.Constant( 'GLX_MAX_PBUFFER_PIXELS', 32792 )
GLX_PRESERVED_CONTENTS = constant.Constant( 'GLX_PRESERVED_CONTENTS', 32795 )
GLX_LARGEST_PBUFFER = constant.Constant( 'GLX_LARGEST_PBUFFER', 32796 )
GLX_WIDTH = constant.Constant( 'GLX_WIDTH', 32797 )
GLX_HEIGHT = constant.Constant( 'GLX_HEIGHT', 32798 )
GLX_EVENT_MASK = constant.Constant( 'GLX_EVENT_MASK', 32799 )
GLX_DAMAGED = constant.Constant( 'GLX_DAMAGED', 32800 )
GLX_SAVED = constant.Constant( 'GLX_SAVED', 32801 )
GLX_WINDOW = constant.Constant( 'GLX_WINDOW', 32802 )
GLX_PBUFFER = constant.Constant( 'GLX_PBUFFER', 32803 )
GLX_PBUFFER_HEIGHT = constant.Constant( 'GLX_PBUFFER_HEIGHT', 32832 )
GLX_PBUFFER_WIDTH = constant.Constant( 'GLX_PBUFFER_WIDTH', 32833 )
GLX_RGBA_BIT = constant.Constant( 'GLX_RGBA_BIT', 1 )
GLX_COLOR_INDEX_BIT = constant.Constant( 'GLX_COLOR_INDEX_BIT', 2 )
GLX_PBUFFER_CLOBBER_MASK = constant.Constant( 'GLX_PBUFFER_CLOBBER_MASK', 134217728 )
GLX_SAMPLE_BUFFERS = constant.Constant( 'GLX_SAMPLE_BUFFERS', 100000 )
GLX_SAMPLES = constant.Constant( 'GLX_SAMPLES', 100001 )
class struct___GLXcontextRec(Structure):
    __slots__ = [
    ]
struct___GLXcontextRec._fields_ = [
    ('_opaque_struct', c_int)
]

class struct___GLXcontextRec(Structure):
    __slots__ = [
    ]
struct___GLXcontextRec._fields_ = [
    ('_opaque_struct', c_int)
]

GLXContext = POINTER(struct___GLXcontextRec) 	# /usr/include/GL/glx.h:178
XID = c_ulong 	# /usr/include/X11/X.h:71
GLXPixmap = XID 	# /usr/include/GL/glx.h:179
GLXDrawable = XID 	# /usr/include/GL/glx.h:180
class struct___GLXFBConfigRec(Structure):
    __slots__ = [
    ]
struct___GLXFBConfigRec._fields_ = [
    ('_opaque_struct', c_int)
]

class struct___GLXFBConfigRec(Structure):
    __slots__ = [
    ]
struct___GLXFBConfigRec._fields_ = [
    ('_opaque_struct', c_int)
]

GLXFBConfig = POINTER(struct___GLXFBConfigRec) 	# /usr/include/GL/glx.h:182
GLXFBConfigID = XID 	# /usr/include/GL/glx.h:183
GLXContextID = XID 	# /usr/include/GL/glx.h:184
GLXWindow = XID 	# /usr/include/GL/glx.h:185
GLXPbuffer = XID 	# /usr/include/GL/glx.h:186
class struct_anon_100(Structure):
    __slots__ = [
        'visual',
        'visualid',
        'screen',
        'depth',
        'class',
        'red_mask',
        'green_mask',
        'blue_mask',
        'colormap_size',
        'bits_per_rgb',
    ]
class struct_anon_17(Structure):
    __slots__ = [
        'ext_data',
        'visualid',
        'class',
        'red_mask',
        'green_mask',
        'blue_mask',
        'bits_per_rgb',
        'map_entries',
    ]
class struct__XExtData(Structure):
    __slots__ = [
        'number',
        'next',
        'free_private',
        'private_data',
    ]
XPointer = c_char_p 	# /usr/include/X11/Xlib.h:108
struct__XExtData._fields_ = [
    ('number', c_int),
    ('next', POINTER(struct__XExtData)),
    ('free_private', POINTER(CFUNCTYPE(c_int, POINTER(struct__XExtData)))),
    ('private_data', XPointer),
]

XExtData = struct__XExtData 	# /usr/include/X11/Xlib.h:187
VisualID = c_ulong 	# /usr/include/X11/X.h:81
struct_anon_17._fields_ = [
    ('ext_data', POINTER(XExtData)),
    ('visualid', VisualID),
    ('class', c_int),
    ('red_mask', c_ulong),
    ('green_mask', c_ulong),
    ('blue_mask', c_ulong),
    ('bits_per_rgb', c_int),
    ('map_entries', c_int),
]

Visual = struct_anon_17 	# /usr/include/X11/Xlib.h:270
struct_anon_100._fields_ = [
    ('visual', POINTER(Visual)),
    ('visualid', VisualID),
    ('screen', c_int),
    ('depth', c_int),
    ('class', c_int),
    ('red_mask', c_ulong),
    ('green_mask', c_ulong),
    ('blue_mask', c_ulong),
    ('colormap_size', c_int),
    ('bits_per_rgb', c_int),
]

XVisualInfo = struct_anon_100 	# /usr/include/X11/Xutil.h:296
class struct__XDisplay(Structure):
    __slots__ = [
    ]
struct__XDisplay._fields_ = [
    ('_opaque_struct', c_int)
]

class struct__XDisplay(Structure):
    __slots__ = [
    ]
struct__XDisplay._fields_ = [
    ('_opaque_struct', c_int)
]

Display = struct__XDisplay 	# /usr/include/X11/Xlib.h:519
glXChooseVisual = platform.createBaseFunction(
    'glXChooseVisual', dll=platform.GL, resultType=POINTER(XVisualInfo), 
    argTypes=[POINTER(Display), c_int, POINTER(c_int)],
    doc='glXChooseVisual( POINTER(Display)(dpy), c_int(screen), POINTER(c_int)(attribList) ) -> POINTER(XVisualInfo)', 
    argNames=['dpy', 'screen', 'attribList'],
)

glXCreateContext = platform.createBaseFunction(
    'glXCreateContext', dll=platform.GL, resultType=GLXContext, 
    argTypes=[POINTER(Display), POINTER(XVisualInfo), GLXContext, c_int],
    doc='glXCreateContext( POINTER(Display)(dpy), POINTER(XVisualInfo)(vis), GLXContext(shareList), c_int(direct) ) -> GLXContext', 
    argNames=['dpy', 'vis', 'shareList', 'direct'],
)

glXDestroyContext = platform.createBaseFunction(
    'glXDestroyContext', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXContext],
    doc='glXDestroyContext( POINTER(Display)(dpy), GLXContext(ctx) ) -> None', 
    argNames=['dpy', 'ctx'],
)

glXMakeCurrent = platform.createBaseFunction(
    'glXMakeCurrent', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXDrawable, GLXContext],
    doc='glXMakeCurrent( POINTER(Display)(dpy), GLXDrawable(drawable), GLXContext(ctx) ) -> c_int', 
    argNames=['dpy', 'drawable', 'ctx'],
)

glXCopyContext = platform.createBaseFunction(
    'glXCopyContext', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXContext, GLXContext, c_ulong],
    doc='glXCopyContext( POINTER(Display)(dpy), GLXContext(src), GLXContext(dst), c_ulong(mask) ) -> None', 
    argNames=['dpy', 'src', 'dst', 'mask'],
)

glXSwapBuffers = platform.createBaseFunction(
    'glXSwapBuffers', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXDrawable],
    doc='glXSwapBuffers( POINTER(Display)(dpy), GLXDrawable(drawable) ) -> None', 
    argNames=['dpy', 'drawable'],
)

Pixmap = XID 	# /usr/include/X11/X.h:107
glXCreateGLXPixmap = platform.createBaseFunction(
    'glXCreateGLXPixmap', dll=platform.GL, resultType=GLXPixmap, 
    argTypes=[POINTER(Display), POINTER(XVisualInfo), Pixmap],
    doc='glXCreateGLXPixmap( POINTER(Display)(dpy), POINTER(XVisualInfo)(visual), Pixmap(pixmap) ) -> GLXPixmap', 
    argNames=['dpy', 'visual', 'pixmap'],
)

glXDestroyGLXPixmap = platform.createBaseFunction(
    'glXDestroyGLXPixmap', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXPixmap],
    doc='glXDestroyGLXPixmap( POINTER(Display)(dpy), GLXPixmap(pixmap) ) -> None', 
    argNames=['dpy', 'pixmap'],
)

glXQueryExtension = platform.createBaseFunction(
    'glXQueryExtension', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), POINTER(c_int), POINTER(c_int)],
    doc='glXQueryExtension( POINTER(Display)(dpy), POINTER(c_int)(errorb), POINTER(c_int)(event) ) -> c_int', 
    argNames=['dpy', 'errorb', 'event'],
)

glXQueryVersion = platform.createBaseFunction(
    'glXQueryVersion', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), POINTER(c_int), POINTER(c_int)],
    doc='glXQueryVersion( POINTER(Display)(dpy), POINTER(c_int)(maj), POINTER(c_int)(min) ) -> c_int', 
    argNames=['dpy', 'maj', 'min'],
)

glXIsDirect = platform.createBaseFunction(
    'glXIsDirect', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXContext],
    doc='glXIsDirect( POINTER(Display)(dpy), GLXContext(ctx) ) -> c_int', 
    argNames=['dpy', 'ctx'],
)

glXGetConfig = platform.createBaseFunction(
    'glXGetConfig', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), POINTER(XVisualInfo), c_int, POINTER(c_int)],
    doc='glXGetConfig( POINTER(Display)(dpy), POINTER(XVisualInfo)(visual), c_int(attrib), POINTER(c_int)(value) ) -> c_int', 
    argNames=['dpy', 'visual', 'attrib', 'value'],
)

glXGetCurrentContext = platform.createBaseFunction(
    'glXGetCurrentContext', dll=platform.GL, resultType=GLXContext, 
    argTypes=[],
    doc='glXGetCurrentContext(  ) -> GLXContext', 
    argNames=[],
)

glXGetCurrentDrawable = platform.createBaseFunction(
    'glXGetCurrentDrawable', dll=platform.GL, resultType=GLXDrawable, 
    argTypes=[],
    doc='glXGetCurrentDrawable(  ) -> GLXDrawable', 
    argNames=[],
)

glXWaitGL = platform.createBaseFunction(
    'glXWaitGL', dll=platform.GL, resultType=None, 
    argTypes=[],
    doc='glXWaitGL(  ) -> None', 
    argNames=[],
)

glXWaitX = platform.createBaseFunction(
    'glXWaitX', dll=platform.GL, resultType=None, 
    argTypes=[],
    doc='glXWaitX(  ) -> None', 
    argNames=[],
)

Font = XID 	# /usr/include/X11/X.h:105
glXUseXFont = platform.createBaseFunction(
    'glXUseXFont', dll=platform.GL, resultType=None, 
    argTypes=[Font, c_int, c_int, c_int],
    doc='glXUseXFont( Font(font), c_int(first), c_int(count), c_int(list) ) -> None', 
    argNames=['font', 'first', 'count', 'list'],
)

glXQueryExtensionsString = platform.createBaseFunction(
    'glXQueryExtensionsString', dll=platform.GL, resultType=c_char_p, 
    argTypes=[POINTER(Display), c_int],
    doc='glXQueryExtensionsString( POINTER(Display)(dpy), c_int(screen) ) -> c_char_p', 
    argNames=['dpy', 'screen'],
)

glXQueryServerString = platform.createBaseFunction(
    'glXQueryServerString', dll=platform.GL, resultType=c_char_p, 
    argTypes=[POINTER(Display), c_int, c_int],
    doc='glXQueryServerString( POINTER(Display)(dpy), c_int(screen), c_int(name) ) -> c_char_p', 
    argNames=['dpy', 'screen', 'name'],
)

glXGetClientString = platform.createBaseFunction(
    'glXGetClientString', dll=platform.GL, resultType=c_char_p, 
    argTypes=[POINTER(Display), c_int],
    doc='glXGetClientString( POINTER(Display)(dpy), c_int(name) ) -> c_char_p', 
    argNames=['dpy', 'name'],
)

glXGetCurrentDisplay = platform.createBaseFunction(
    'glXGetCurrentDisplay', dll=platform.GL, resultType=POINTER(Display), 
    argTypes=[],
    doc='glXGetCurrentDisplay(  ) -> POINTER(Display)', 
    argNames=[],
)

glXChooseFBConfig = platform.createBaseFunction(
    'glXChooseFBConfig', dll=platform.GL, resultType=POINTER(GLXFBConfig), 
    argTypes=[POINTER(Display), c_int, POINTER(c_int), POINTER(c_int)],
    doc='glXChooseFBConfig( POINTER(Display)(dpy), c_int(screen), POINTER(c_int)(attribList), POINTER(c_int)(nitems) ) -> POINTER(GLXFBConfig)', 
    argNames=['dpy', 'screen', 'attribList', 'nitems'],
)

glXGetFBConfigAttrib = platform.createBaseFunction(
    'glXGetFBConfigAttrib', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXFBConfig, c_int, POINTER(c_int)],
    doc='glXGetFBConfigAttrib( POINTER(Display)(dpy), GLXFBConfig(config), c_int(attribute), POINTER(c_int)(value) ) -> c_int', 
    argNames=['dpy', 'config', 'attribute', 'value'],
)

glXGetFBConfigs = platform.createBaseFunction(
    'glXGetFBConfigs', dll=platform.GL, resultType=POINTER(GLXFBConfig), 
    argTypes=[POINTER(Display), c_int, POINTER(c_int)],
    doc='glXGetFBConfigs( POINTER(Display)(dpy), c_int(screen), POINTER(c_int)(nelements) ) -> POINTER(GLXFBConfig)', 
    argNames=['dpy', 'screen', 'nelements'],
)

glXGetVisualFromFBConfig = platform.createBaseFunction(
    'glXGetVisualFromFBConfig', dll=platform.GL, resultType=POINTER(XVisualInfo), 
    argTypes=[POINTER(Display), GLXFBConfig],
    doc='glXGetVisualFromFBConfig( POINTER(Display)(dpy), GLXFBConfig(config) ) -> POINTER(XVisualInfo)', 
    argNames=['dpy', 'config'],
)

Window = XID 	# /usr/include/X11/X.h:101
glXCreateWindow = platform.createBaseFunction(
    'glXCreateWindow', dll=platform.GL, resultType=GLXWindow, 
    argTypes=[POINTER(Display), GLXFBConfig, Window, POINTER(c_int)],
    doc='glXCreateWindow( POINTER(Display)(dpy), GLXFBConfig(config), Window(win), POINTER(c_int)(attribList) ) -> GLXWindow', 
    argNames=['dpy', 'config', 'win', 'attribList'],
)

glXDestroyWindow = platform.createBaseFunction(
    'glXDestroyWindow', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXWindow],
    doc='glXDestroyWindow( POINTER(Display)(dpy), GLXWindow(window) ) -> None', 
    argNames=['dpy', 'window'],
)

glXCreatePixmap = platform.createBaseFunction(
    'glXCreatePixmap', dll=platform.GL, resultType=GLXPixmap, 
    argTypes=[POINTER(Display), GLXFBConfig, Pixmap, POINTER(c_int)],
    doc='glXCreatePixmap( POINTER(Display)(dpy), GLXFBConfig(config), Pixmap(pixmap), POINTER(c_int)(attribList) ) -> GLXPixmap', 
    argNames=['dpy', 'config', 'pixmap', 'attribList'],
)

glXDestroyPixmap = platform.createBaseFunction(
    'glXDestroyPixmap', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXPixmap],
    doc='glXDestroyPixmap( POINTER(Display)(dpy), GLXPixmap(pixmap) ) -> None', 
    argNames=['dpy', 'pixmap'],
)

glXCreatePbuffer = platform.createBaseFunction(
    'glXCreatePbuffer', dll=platform.GL, resultType=GLXPbuffer, 
    argTypes=[POINTER(Display), GLXFBConfig, POINTER(c_int)],
    doc='glXCreatePbuffer( POINTER(Display)(dpy), GLXFBConfig(config), POINTER(c_int)(attribList) ) -> GLXPbuffer', 
    argNames=['dpy', 'config', 'attribList'],
)

glXDestroyPbuffer = platform.createBaseFunction(
    'glXDestroyPbuffer', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXPbuffer],
    doc='glXDestroyPbuffer( POINTER(Display)(dpy), GLXPbuffer(pbuf) ) -> None', 
    argNames=['dpy', 'pbuf'],
)

glXQueryDrawable = platform.createBaseFunction(
    'glXQueryDrawable', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXDrawable, c_int, POINTER(c_uint)],
    doc='glXQueryDrawable( POINTER(Display)(dpy), GLXDrawable(draw), c_int(attribute), POINTER(c_uint)(value) ) -> None', 
    argNames=['dpy', 'draw', 'attribute', 'value'],
)

glXCreateNewContext = platform.createBaseFunction(
    'glXCreateNewContext', dll=platform.GL, resultType=GLXContext, 
    argTypes=[POINTER(Display), GLXFBConfig, c_int, GLXContext, c_int],
    doc='glXCreateNewContext( POINTER(Display)(dpy), GLXFBConfig(config), c_int(renderType), GLXContext(shareList), c_int(direct) ) -> GLXContext', 
    argNames=['dpy', 'config', 'renderType', 'shareList', 'direct'],
)

glXMakeContextCurrent = platform.createBaseFunction(
    'glXMakeContextCurrent', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXDrawable, GLXDrawable, GLXContext],
    doc='glXMakeContextCurrent( POINTER(Display)(dpy), GLXDrawable(draw), GLXDrawable(read), GLXContext(ctx) ) -> c_int', 
    argNames=['dpy', 'draw', 'read', 'ctx'],
)

glXGetCurrentReadDrawable = platform.createBaseFunction(
    'glXGetCurrentReadDrawable', dll=platform.GL, resultType=GLXDrawable, 
    argTypes=[],
    doc='glXGetCurrentReadDrawable(  ) -> GLXDrawable', 
    argNames=[],
)

glXQueryContext = platform.createBaseFunction(
    'glXQueryContext', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXContext, c_int, POINTER(c_int)],
    doc='glXQueryContext( POINTER(Display)(dpy), GLXContext(ctx), c_int(attribute), POINTER(c_int)(value) ) -> c_int', 
    argNames=['dpy', 'ctx', 'attribute', 'value'],
)

glXSelectEvent = platform.createBaseFunction(
    'glXSelectEvent', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXDrawable, c_ulong],
    doc='glXSelectEvent( POINTER(Display)(dpy), GLXDrawable(drawable), c_ulong(mask) ) -> None', 
    argNames=['dpy', 'drawable', 'mask'],
)

glXGetSelectedEvent = platform.createBaseFunction(
    'glXGetSelectedEvent', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), GLXDrawable, POINTER(c_ulong)],
    doc='glXGetSelectedEvent( POINTER(Display)(dpy), GLXDrawable(drawable), POINTER(c_ulong)(mask) ) -> None', 
    argNames=['dpy', 'drawable', 'mask'],
)

GLubyte = c_ubyte 	# /usr/include/GL/gl.h:154
glXGetProcAddress = platform.createBaseFunction(
    'glXGetProcAddress', dll=platform.GL, resultType=POINTER(CFUNCTYPE(None)), 
    argTypes=[POINTER(GLubyte)],
    doc='glXGetProcAddress( POINTER(GLubyte)(procname) ) -> POINTER(CFUNCTYPE(None))', 
    argNames=['procname'],
)

# GLXEXT_LEGACY (/usr/include/GL/glx.h:298)
# VERSION_1_3 (/usr/include/GL/glxext.h:53)
# VERSION_1_4 (/usr/include/GL/glxext.h:112)
# ARB_get_proc_address (/usr/include/GL/glxext.h:117)
# ARB_multisample (/usr/include/GL/glxext.h:120)
# ARB_fbconfig_float (/usr/include/GL/glxext.h:125)
# SGIS_multisample (/usr/include/GL/glxext.h:130)
# EXT_visual_info (/usr/include/GL/glxext.h:135)
# SGI_swap_control (/usr/include/GL/glxext.h:154)
# SGI_video_sync (/usr/include/GL/glxext.h:157)
# SGI_make_current_read (/usr/include/GL/glxext.h:160)
# SGIX_video_source (/usr/include/GL/glxext.h:163)
# EXT_visual_rating (/usr/include/GL/glxext.h:166)
# EXT_import_context (/usr/include/GL/glxext.h:173)
# SGIX_fbconfig (/usr/include/GL/glxext.h:179)
# SGIX_pbuffer (/usr/include/GL/glxext.h:193)
# SGI_cushion (/usr/include/GL/glxext.h:221)
# SGIX_video_resize (/usr/include/GL/glxext.h:224)
# SGIX_dmbuffer (/usr/include/GL/glxext.h:229)
# SGIX_swap_group (/usr/include/GL/glxext.h:233)
# SGIX_swap_barrier (/usr/include/GL/glxext.h:236)
# SGIS_blended_overlay (/usr/include/GL/glxext.h:239)
# SGIS_shared_multisample (/usr/include/GL/glxext.h:243)
# SUN_get_transparent_index (/usr/include/GL/glxext.h:248)
# 3DFX_multisample (/usr/include/GL/glxext.h:251)
# MESA_copy_sub_buffer (/usr/include/GL/glxext.h:256)
# MESA_pixmap_colormap (/usr/include/GL/glxext.h:259)
# MESA_release_buffers (/usr/include/GL/glxext.h:262)
# MESA_set_3dfx_mode (/usr/include/GL/glxext.h:265)
# SGIX_visual_select_group (/usr/include/GL/glxext.h:270)
# OML_swap_method (/usr/include/GL/glxext.h:274)
# OML_sync_control (/usr/include/GL/glxext.h:281)
# NV_float_buffer (/usr/include/GL/glxext.h:284)
# SGIX_hyperpipe (/usr/include/GL/glxext.h:288)
# MESA_agp_offset (/usr/include/GL/glxext.h:301)
# EXT_fbconfig_packed_float (/usr/include/GL/glxext.h:304)
# EXT_framebuffer_sRGB (/usr/include/GL/glxext.h:309)
# EXT_texture_from_pixmap (/usr/include/GL/glxext.h:313)
# ARB_get_proc_address (/usr/include/GL/glxext.h:352)
# SGIX_video_source (/usr/include/GL/glxext.h:356)
# SGIX_fbconfig (/usr/include/GL/glxext.h:360)
# SGIX_pbuffer (/usr/include/GL/glxext.h:365)
# VERSION_1_3 (/usr/include/GL/glxext.h:419)
# VERSION_1_4 (/usr/include/GL/glxext.h:461)
# ARB_get_proc_address (/usr/include/GL/glxext.h:469)
# ARB_multisample (/usr/include/GL/glxext.h:477)
# ARB_fbconfig_float (/usr/include/GL/glxext.h:481)
# SGIS_multisample (/usr/include/GL/glxext.h:485)
# EXT_visual_info (/usr/include/GL/glxext.h:489)
# SGI_swap_control (/usr/include/GL/glxext.h:493)
# SGI_video_sync (/usr/include/GL/glxext.h:501)
# SGI_make_current_read (/usr/include/GL/glxext.h:511)
# SGIX_video_source (/usr/include/GL/glxext.h:521)
# EXT_visual_rating (/usr/include/GL/glxext.h:533)
# EXT_import_context (/usr/include/GL/glxext.h:537)
# SGIX_fbconfig (/usr/include/GL/glxext.h:553)
# SGIX_pbuffer (/usr/include/GL/glxext.h:571)
# SGI_cushion (/usr/include/GL/glxext.h:587)
# SGIX_video_resize (/usr/include/GL/glxext.h:595)
# SGIX_dmbuffer (/usr/include/GL/glxext.h:611)
# SGIX_swap_group (/usr/include/GL/glxext.h:621)
# SGIX_swap_barrier (/usr/include/GL/glxext.h:629)
# SUN_get_transparent_index (/usr/include/GL/glxext.h:639)
# MESA_copy_sub_buffer (/usr/include/GL/glxext.h:647)
# MESA_pixmap_colormap (/usr/include/GL/glxext.h:655)
# MESA_release_buffers (/usr/include/GL/glxext.h:663)
# MESA_set_3dfx_mode (/usr/include/GL/glxext.h:671)
# SGIX_visual_select_group (/usr/include/GL/glxext.h:679)
# OML_swap_method (/usr/include/GL/glxext.h:683)
# OML_sync_control (/usr/include/GL/glxext.h:687)
# NV_float_buffer (/usr/include/GL/glxext.h:703)
# SGIX_hyperpipe (/usr/include/GL/glxext.h:707)
# MESA_agp_offset (/usr/include/GL/glxext.h:754)
# EXT_fbconfig_packed_float (/usr/include/GL/glxext.h:762)
# EXT_framebuffer_sRGB (/usr/include/GL/glxext.h:766)
# EXT_texture_from_pixmap (/usr/include/GL/glxext.h:770)
# NV_vertex_array_range (/usr/include/GL/glx.h:330)
GLsizei = c_int 	# /usr/include/GL/gl.h:157
GLfloat = c_float 	# /usr/include/GL/gl.h:158
glXAllocateMemoryNV = platform.createBaseFunction(
    'glXAllocateMemoryNV', dll=platform.GL, resultType=POINTER(c_void), 
    argTypes=[GLsizei, GLfloat, GLfloat, GLfloat],
    doc='glXAllocateMemoryNV( GLsizei(size), GLfloat(readfreq), GLfloat(writefreq), GLfloat(priority) ) -> POINTER(c_void)', 
    argNames=['size', 'readfreq', 'writefreq', 'priority'],
)

GLvoid = None 	# /usr/include/GL/gl.h:150
glXFreeMemoryNV = platform.createBaseFunction(
    'glXFreeMemoryNV', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(GLvoid)],
    doc='glXFreeMemoryNV( POINTER(GLvoid)(pointer) ) -> None', 
    argNames=['pointer'],
)

# MESA_allocate_memory (/usr/include/GL/glx.h:344)
GLX_MESA_allocate_memory = constant.Constant( 'GLX_MESA_allocate_memory', 1 )
glXAllocateMemoryMESA = platform.createBaseFunction(
    'glXAllocateMemoryMESA', dll=platform.GL, resultType=POINTER(c_void), 
    argTypes=[POINTER(Display), c_int, c_size_t, c_float, c_float, c_float],
    doc='glXAllocateMemoryMESA( POINTER(Display)(dpy), c_int(scrn), c_size_t(size), c_float(readfreq), c_float(writefreq), c_float(priority) ) -> POINTER(c_void)', 
    argNames=['dpy', 'scrn', 'size', 'readfreq', 'writefreq', 'priority'],
)

glXFreeMemoryMESA = platform.createBaseFunction(
    'glXFreeMemoryMESA', dll=platform.GL, resultType=None, 
    argTypes=[POINTER(Display), c_int, POINTER(None)],
    doc='glXFreeMemoryMESA( POINTER(Display)(dpy), c_int(scrn), POINTER(None)(pointer) ) -> None', 
    argNames=['dpy', 'scrn', 'pointer'],
)

GLuint = c_uint 	# /usr/include/GL/gl.h:156
glXGetMemoryOffsetMESA = platform.createBaseFunction(
    'glXGetMemoryOffsetMESA', dll=platform.GL, resultType=GLuint, 
    argTypes=[POINTER(Display), c_int, POINTER(None)],
    doc='glXGetMemoryOffsetMESA( POINTER(Display)(dpy), c_int(scrn), POINTER(None)(pointer) ) -> GLuint', 
    argNames=['dpy', 'scrn', 'pointer'],
)

# ARB_render_texture (/usr/include/GL/glx.h:361)
GLX_ARB_render_texture = constant.Constant( 'GLX_ARB_render_texture', 1 )
glXBindTexImageARB = platform.createBaseFunction(
    'glXBindTexImageARB', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXPbuffer, c_int],
    doc='glXBindTexImageARB( POINTER(Display)(dpy), GLXPbuffer(pbuffer), c_int(buffer) ) -> c_int', 
    argNames=['dpy', 'pbuffer', 'buffer'],
)

glXReleaseTexImageARB = platform.createBaseFunction(
    'glXReleaseTexImageARB', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXPbuffer, c_int],
    doc='glXReleaseTexImageARB( POINTER(Display)(dpy), GLXPbuffer(pbuffer), c_int(buffer) ) -> c_int', 
    argNames=['dpy', 'pbuffer', 'buffer'],
)

glXDrawableAttribARB = platform.createBaseFunction(
    'glXDrawableAttribARB', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXDrawable, POINTER(c_int)],
    doc='glXDrawableAttribARB( POINTER(Display)(dpy), GLXDrawable(draw), POINTER(c_int)(attribList) ) -> c_int', 
    argNames=['dpy', 'draw', 'attribList'],
)

# NV_float_buffer (/usr/include/GL/glx.h:374)
# MESA_swap_frame_usage (/usr/include/GL/glx.h:386)
GLX_MESA_swap_frame_usage = constant.Constant( 'GLX_MESA_swap_frame_usage', 1 )
glXGetFrameUsageMESA = platform.createBaseFunction(
    'glXGetFrameUsageMESA', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXDrawable, POINTER(c_float)],
    doc='glXGetFrameUsageMESA( POINTER(Display)(dpy), GLXDrawable(drawable), POINTER(c_float)(usage) ) -> c_int', 
    argNames=['dpy', 'drawable', 'usage'],
)

glXBeginFrameTrackingMESA = platform.createBaseFunction(
    'glXBeginFrameTrackingMESA', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXDrawable],
    doc='glXBeginFrameTrackingMESA( POINTER(Display)(dpy), GLXDrawable(drawable) ) -> c_int', 
    argNames=['dpy', 'drawable'],
)

glXEndFrameTrackingMESA = platform.createBaseFunction(
    'glXEndFrameTrackingMESA', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXDrawable],
    doc='glXEndFrameTrackingMESA( POINTER(Display)(dpy), GLXDrawable(drawable) ) -> c_int', 
    argNames=['dpy', 'drawable'],
)

glXQueryFrameTrackingMESA = platform.createBaseFunction(
    'glXQueryFrameTrackingMESA', dll=platform.GL, resultType=c_int, 
    argTypes=[POINTER(Display), GLXDrawable, POINTER(c_int64), POINTER(c_int64), POINTER(c_float)],
    doc='glXQueryFrameTrackingMESA( POINTER(Display)(dpy), GLXDrawable(drawable), POINTER(c_int64)(swapCount), POINTER(c_int64)(missedFrames), POINTER(c_float)(lastMissedUsage) ) -> c_int', 
    argNames=['dpy', 'drawable', 'swapCount', 'missedFrames', 'lastMissedUsage'],
)

# MESA_swap_control (/usr/include/GL/glx.h:406)
GLX_MESA_swap_control = constant.Constant( 'GLX_MESA_swap_control', 1 )
glXSwapIntervalMESA = platform.createBaseFunction(
    'glXSwapIntervalMESA', dll=platform.GL, resultType=c_int, 
    argTypes=[c_uint],
    doc='glXSwapIntervalMESA( c_uint(interval) ) -> c_int', 
    argNames=['interval'],
)

glXGetSwapIntervalMESA = platform.createBaseFunction(
    'glXGetSwapIntervalMESA', dll=platform.GL, resultType=c_int, 
    argTypes=[],
    doc='glXGetSwapIntervalMESA(  ) -> c_int', 
    argNames=[],
)

# EXT_texture_from_pixmap (/usr/include/GL/glx.h:423)
class struct_anon_108(Structure):
    __slots__ = [
        'event_type',
        'draw_type',
        'serial',
        'send_event',
        'display',
        'drawable',
        'buffer_mask',
        'aux_buffer',
        'x',
        'y',
        'width',
        'height',
        'count',
    ]
struct_anon_108._fields_ = [
    ('event_type', c_int),
    ('draw_type', c_int),
    ('serial', c_ulong),
    ('send_event', c_int),
    ('display', POINTER(Display)),
    ('drawable', GLXDrawable),
    ('buffer_mask', c_uint),
    ('aux_buffer', c_uint),
    ('x', c_int),
    ('y', c_int),
    ('width', c_int),
    ('height', c_int),
    ('count', c_int),
]

GLXPbufferClobberEvent = struct_anon_108 	# /usr/include/GL/glx.h:489
class struct___GLXEvent(Union):
    __slots__ = [
        'glxpbufferclobber',
        'pad',
    ]
struct___GLXEvent._fields_ = [
    ('glxpbufferclobber', GLXPbufferClobberEvent),
    ('pad', c_long * 24),
]

GLXEvent = struct___GLXEvent 	# /usr/include/GL/glx.h:494

__all__ = ['GLX_VERSION_1_1', 'GLX_VERSION_1_2', 'GLX_VERSION_1_3',
'GLX_VERSION_1_4', 'GLX_USE_GL', 'GLX_BUFFER_SIZE', 'GLX_LEVEL', 'GLX_RGBA',
'GLX_DOUBLEBUFFER', 'GLX_STEREO', 'GLX_AUX_BUFFERS', 'GLX_RED_SIZE',
'GLX_GREEN_SIZE', 'GLX_BLUE_SIZE', 'GLX_ALPHA_SIZE', 'GLX_DEPTH_SIZE',
'GLX_STENCIL_SIZE', 'GLX_ACCUM_RED_SIZE', 'GLX_ACCUM_GREEN_SIZE',
'GLX_ACCUM_BLUE_SIZE', 'GLX_ACCUM_ALPHA_SIZE', 'GLX_BAD_SCREEN',
'GLX_BAD_ATTRIBUTE', 'GLX_NO_EXTENSION', 'GLX_BAD_VISUAL', 'GLX_BAD_CONTEXT',
'GLX_BAD_VALUE', 'GLX_BAD_ENUM', 'GLX_VENDOR', 'GLX_VERSION',
'GLX_EXTENSIONS', 'GLX_CONFIG_CAVEAT', 'GLX_DONT_CARE', 'GLX_X_VISUAL_TYPE',
'GLX_TRANSPARENT_TYPE', 'GLX_TRANSPARENT_INDEX_VALUE',
'GLX_TRANSPARENT_RED_VALUE', 'GLX_TRANSPARENT_GREEN_VALUE',
'GLX_TRANSPARENT_BLUE_VALUE', 'GLX_TRANSPARENT_ALPHA_VALUE', 'GLX_WINDOW_BIT',
'GLX_PIXMAP_BIT', 'GLX_PBUFFER_BIT', 'GLX_AUX_BUFFERS_BIT',
'GLX_FRONT_LEFT_BUFFER_BIT', 'GLX_FRONT_RIGHT_BUFFER_BIT',
'GLX_BACK_LEFT_BUFFER_BIT', 'GLX_BACK_RIGHT_BUFFER_BIT',
'GLX_DEPTH_BUFFER_BIT', 'GLX_STENCIL_BUFFER_BIT', 'GLX_ACCUM_BUFFER_BIT',
'GLX_NONE', 'GLX_SLOW_CONFIG', 'GLX_TRUE_COLOR', 'GLX_DIRECT_COLOR',
'GLX_PSEUDO_COLOR', 'GLX_STATIC_COLOR', 'GLX_GRAY_SCALE', 'GLX_STATIC_GRAY',
'GLX_TRANSPARENT_RGB', 'GLX_TRANSPARENT_INDEX', 'GLX_VISUAL_ID', 'GLX_SCREEN',
'GLX_NON_CONFORMANT_CONFIG', 'GLX_DRAWABLE_TYPE', 'GLX_RENDER_TYPE',
'GLX_X_RENDERABLE', 'GLX_FBCONFIG_ID', 'GLX_RGBA_TYPE',
'GLX_COLOR_INDEX_TYPE', 'GLX_MAX_PBUFFER_WIDTH', 'GLX_MAX_PBUFFER_HEIGHT',
'GLX_MAX_PBUFFER_PIXELS', 'GLX_PRESERVED_CONTENTS', 'GLX_LARGEST_PBUFFER',
'GLX_WIDTH', 'GLX_HEIGHT', 'GLX_EVENT_MASK', 'GLX_DAMAGED', 'GLX_SAVED',
'GLX_WINDOW', 'GLX_PBUFFER', 'GLX_PBUFFER_HEIGHT', 'GLX_PBUFFER_WIDTH',
'GLX_RGBA_BIT', 'GLX_COLOR_INDEX_BIT', 'GLX_PBUFFER_CLOBBER_MASK',
'GLX_SAMPLE_BUFFERS', 'GLX_SAMPLES', 'GLXContext', 'GLXPixmap', 'GLXDrawable',
'GLXFBConfig', 'GLXFBConfigID', 'GLXContextID', 'GLXWindow', 'GLXPbuffer',
'glXChooseVisual', 'glXCreateContext', 'glXDestroyContext', 'glXMakeCurrent',
'glXCopyContext', 'glXSwapBuffers', 'glXCreateGLXPixmap',
'glXDestroyGLXPixmap', 'glXQueryExtension', 'glXQueryVersion', 'glXIsDirect',
'glXGetConfig', 'glXGetCurrentContext', 'glXGetCurrentDrawable', 'glXWaitGL',
'glXWaitX', 'glXUseXFont', 'glXQueryExtensionsString', 'glXQueryServerString',
'glXGetClientString', 'glXGetCurrentDisplay', 'glXChooseFBConfig',
'glXGetFBConfigAttrib', 'glXGetFBConfigs', 'glXGetVisualFromFBConfig',
'glXCreateWindow', 'glXDestroyWindow', 'glXCreatePixmap', 'glXDestroyPixmap',
'glXCreatePbuffer', 'glXDestroyPbuffer', 'glXQueryDrawable',
'glXCreateNewContext', 'glXMakeContextCurrent', 'glXGetCurrentReadDrawable',
'glXQueryContext', 'glXSelectEvent', 'glXGetSelectedEvent',
'glXGetProcAddress', 'glXAllocateMemoryNV', 'glXFreeMemoryNV',
'GLX_MESA_allocate_memory', 'glXAllocateMemoryMESA', 'glXFreeMemoryMESA',
'glXGetMemoryOffsetMESA', 'GLX_ARB_render_texture', 'glXBindTexImageARB',
'glXReleaseTexImageARB', 'glXDrawableAttribARB', 'GLX_MESA_swap_frame_usage',
'glXGetFrameUsageMESA', 'glXBeginFrameTrackingMESA',
'glXEndFrameTrackingMESA', 'glXQueryFrameTrackingMESA',
'GLX_MESA_swap_control', 'glXSwapIntervalMESA', 'glXGetSwapIntervalMESA',
'GLXPbufferClobberEvent', 'GLXEvent']
# END GENERATED CONTENT (do not edit above this line)



'''OpenGL extension ARB.texture_compression

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_texture_compression'
_DEPRECATED = False
GL_COMPRESSED_ALPHA_ARB = constant.Constant( 'GL_COMPRESSED_ALPHA_ARB', 0x84E9 )
GL_COMPRESSED_LUMINANCE_ARB = constant.Constant( 'GL_COMPRESSED_LUMINANCE_ARB', 0x84EA )
GL_COMPRESSED_LUMINANCE_ALPHA_ARB = constant.Constant( 'GL_COMPRESSED_LUMINANCE_ALPHA_ARB', 0x84EB )
GL_COMPRESSED_INTENSITY_ARB = constant.Constant( 'GL_COMPRESSED_INTENSITY_ARB', 0x84EC )
GL_COMPRESSED_RGB_ARB = constant.Constant( 'GL_COMPRESSED_RGB_ARB', 0x84ED )
GL_COMPRESSED_RGBA_ARB = constant.Constant( 'GL_COMPRESSED_RGBA_ARB', 0x84EE )
GL_TEXTURE_COMPRESSION_HINT_ARB = constant.Constant( 'GL_TEXTURE_COMPRESSION_HINT_ARB', 0x84EF )
glget.addGLGetConstant( GL_TEXTURE_COMPRESSION_HINT_ARB, (1,) )
GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB = constant.Constant( 'GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB', 0x86A0 )
GL_TEXTURE_COMPRESSED_ARB = constant.Constant( 'GL_TEXTURE_COMPRESSED_ARB', 0x86A1 )
GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB = constant.Constant( 'GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB', 0x86A2 )
glget.addGLGetConstant( GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB, (1,) )
GL_COMPRESSED_TEXTURE_FORMATS_ARB = constant.Constant( 'GL_COMPRESSED_TEXTURE_FORMATS_ARB', 0x86A3 )
glget.addGLGetConstant( GL_COMPRESSED_TEXTURE_FORMATS_ARB, (1,) )
glCompressedTexImage3DARB = platform.createExtensionFunction( 
'glCompressedTexImage3DARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTexImage3DARB(GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLsizei(imageSize), c_void_p(data)) -> None',
argNames=('target','level','internalformat','width','height','depth','border','imageSize','data',),
deprecated=_DEPRECATED,
)

glCompressedTexImage2DARB = platform.createExtensionFunction( 
'glCompressedTexImage2DARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTexImage2DARB(GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLint(border), GLsizei(imageSize), c_void_p(data)) -> None',
argNames=('target','level','internalformat','width','height','border','imageSize','data',),
deprecated=_DEPRECATED,
)

glCompressedTexImage1DARB = platform.createExtensionFunction( 
'glCompressedTexImage1DARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTexImage1DARB(GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLint(border), GLsizei(imageSize), c_void_p(data)) -> None',
argNames=('target','level','internalformat','width','border','imageSize','data',),
deprecated=_DEPRECATED,
)

glCompressedTexSubImage3DARB = platform.createExtensionFunction( 
'glCompressedTexSubImage3DARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTexSubImage3DARB(GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLsizei(imageSize), c_void_p(data)) -> None',
argNames=('target','level','xoffset','yoffset','zoffset','width','height','depth','format','imageSize','data',),
deprecated=_DEPRECATED,
)

glCompressedTexSubImage2DARB = platform.createExtensionFunction( 
'glCompressedTexSubImage2DARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTexSubImage2DARB(GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLsizei(width), GLsizei(height), GLenum(format), GLsizei(imageSize), c_void_p(data)) -> None',
argNames=('target','level','xoffset','yoffset','width','height','format','imageSize','data',),
deprecated=_DEPRECATED,
)

glCompressedTexSubImage1DARB = platform.createExtensionFunction( 
'glCompressedTexSubImage1DARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTexSubImage1DARB(GLenum(target), GLint(level), GLint(xoffset), GLsizei(width), GLenum(format), GLsizei(imageSize), c_void_p(data)) -> None',
argNames=('target','level','xoffset','width','format','imageSize','data',),
deprecated=_DEPRECATED,
)

glGetCompressedTexImageARB = platform.createExtensionFunction( 
'glGetCompressedTexImageARB',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,ctypes.c_void_p,),
doc='glGetCompressedTexImageARB(GLenum(target), GLint(level), c_void_p(img)) -> None',
argNames=('target','level','img',),
deprecated=_DEPRECATED,
)


def glInitTextureCompressionARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ATI.pixel_format_float

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_pixel_format_float'
_DEPRECATED = False
GL_TYPE_RGBA_FLOAT_ATI = constant.Constant( 'GL_TYPE_RGBA_FLOAT_ATI', 0x8820 )
GL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI = constant.Constant( 'GL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI', 0x8835 )
glget.addGLGetConstant( GL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI, (4,) )


def glInitPixelFormatFloatATI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.texture_shader3

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_texture_shader3'
_DEPRECATED = False
GL_OFFSET_PROJECTIVE_TEXTURE_2D_NV = constant.Constant( 'GL_OFFSET_PROJECTIVE_TEXTURE_2D_NV', 0x8850 )
GL_OFFSET_PROJECTIVE_TEXTURE_2D_SCALE_NV = constant.Constant( 'GL_OFFSET_PROJECTIVE_TEXTURE_2D_SCALE_NV', 0x8851 )
GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_NV = constant.Constant( 'GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_NV', 0x8852 )
GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_SCALE_NV = constant.Constant( 'GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_SCALE_NV', 0x8853 )
GL_OFFSET_HILO_TEXTURE_2D_NV = constant.Constant( 'GL_OFFSET_HILO_TEXTURE_2D_NV', 0x8854 )
GL_OFFSET_HILO_TEXTURE_RECTANGLE_NV = constant.Constant( 'GL_OFFSET_HILO_TEXTURE_RECTANGLE_NV', 0x8855 )
GL_OFFSET_HILO_PROJECTIVE_TEXTURE_2D_NV = constant.Constant( 'GL_OFFSET_HILO_PROJECTIVE_TEXTURE_2D_NV', 0x8856 )
GL_OFFSET_HILO_PROJECTIVE_TEXTURE_RECTANGLE_NV = constant.Constant( 'GL_OFFSET_HILO_PROJECTIVE_TEXTURE_RECTANGLE_NV', 0x8857 )
GL_DEPENDENT_HILO_TEXTURE_2D_NV = constant.Constant( 'GL_DEPENDENT_HILO_TEXTURE_2D_NV', 0x8858 )
GL_DEPENDENT_RGB_TEXTURE_3D_NV = constant.Constant( 'GL_DEPENDENT_RGB_TEXTURE_3D_NV', 0x8859 )
GL_DEPENDENT_RGB_TEXTURE_CUBE_MAP_NV = constant.Constant( 'GL_DEPENDENT_RGB_TEXTURE_CUBE_MAP_NV', 0x885A )
GL_DOT_PRODUCT_PASS_THROUGH_NV = constant.Constant( 'GL_DOT_PRODUCT_PASS_THROUGH_NV', 0x885B )
GL_DOT_PRODUCT_TEXTURE_1D_NV = constant.Constant( 'GL_DOT_PRODUCT_TEXTURE_1D_NV', 0x885C )
GL_DOT_PRODUCT_AFFINE_DEPTH_REPLACE_NV = constant.Constant( 'GL_DOT_PRODUCT_AFFINE_DEPTH_REPLACE_NV', 0x885D )
GL_HILO8_NV = constant.Constant( 'GL_HILO8_NV', 0x885E )
GL_SIGNED_HILO8_NV = constant.Constant( 'GL_SIGNED_HILO8_NV', 0x885F )
GL_FORCE_BLUE_TO_ONE_NV = constant.Constant( 'GL_FORCE_BLUE_TO_ONE_NV', 0x8860 )


def glInitTextureShader3NV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.gpu_program_parameters

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.gpu_program_parameters to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a new set of procedures to load multiple 
	consecutive program environment parameters more efficiently, via a single 
	GL call instead of multiple calls.  This will reduce the amount of CPU 
	overhead involved in loading parameters. 
	
	With the existing ARB_vertex_program and ARB_fragment_program APIs, 
	program parameters must be loaded one at a time, via separate calls. 
	While the NV_vertex_program extension provides a set of similar functions 
	that can be used to load program environment parameters (which are 
	equivalent to "program parameters" in NV_vertex_program), no such function 
	exists for program local parameters. 

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/gpu_program_parameters.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.EXT.gpu_program_parameters import *
### END AUTOGENERATED SECTION


'''OpenGL extension EXT.paletted_texture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_paletted_texture'
_DEPRECATED = False
GL_COLOR_INDEX1_EXT = constant.Constant( 'GL_COLOR_INDEX1_EXT', 0x80E2 )
GL_COLOR_INDEX2_EXT = constant.Constant( 'GL_COLOR_INDEX2_EXT', 0x80E3 )
GL_COLOR_INDEX4_EXT = constant.Constant( 'GL_COLOR_INDEX4_EXT', 0x80E4 )
GL_COLOR_INDEX8_EXT = constant.Constant( 'GL_COLOR_INDEX8_EXT', 0x80E5 )
GL_COLOR_INDEX12_EXT = constant.Constant( 'GL_COLOR_INDEX12_EXT', 0x80E6 )
GL_COLOR_INDEX16_EXT = constant.Constant( 'GL_COLOR_INDEX16_EXT', 0x80E7 )
GL_TEXTURE_INDEX_SIZE_EXT = constant.Constant( 'GL_TEXTURE_INDEX_SIZE_EXT', 0x80ED )
glColorTableEXT = platform.createExtensionFunction( 
'glColorTableEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLsizei,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glColorTableEXT(GLenum(target), GLenum(internalFormat), GLsizei(width), GLenum(format), GLenum(type), c_void_p(table)) -> None',
argNames=('target','internalFormat','width','format','type','table',),
deprecated=_DEPRECATED,
)

glGetColorTableEXT = platform.createExtensionFunction( 
'glGetColorTableEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,ctypes.c_void_p,),
doc='glGetColorTableEXT(GLenum(target), GLenum(format), GLenum(type), c_void_p(data)) -> None',
argNames=('target','format','type','data',),
deprecated=_DEPRECATED,
)

glGetColorTableParameterivEXT = platform.createExtensionFunction( 
'glGetColorTableParameterivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetColorTableParameterivEXT(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetColorTableParameterfvEXT = platform.createExtensionFunction( 
'glGetColorTableParameterfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetColorTableParameterfvEXT(GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)


def glInitPalettedTextureEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.texture_query_lod

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_query_lod to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a new set of fragment shader texture
	functions (textureLOD) that return the results of automatic
	level-of-detail computations that would be performed if a texture
	lookup were performed.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_query_lod.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.ARB.texture_query_lod import *
### END AUTOGENERATED SECTION


'''OpenGL extension NV.register_combiners

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_register_combiners'
_DEPRECATED = False
GL_REGISTER_COMBINERS_NV = constant.Constant( 'GL_REGISTER_COMBINERS_NV', 0x8522 )
glget.addGLGetConstant( GL_REGISTER_COMBINERS_NV, (1,) )
GL_VARIABLE_A_NV = constant.Constant( 'GL_VARIABLE_A_NV', 0x8523 )
GL_VARIABLE_B_NV = constant.Constant( 'GL_VARIABLE_B_NV', 0x8524 )
GL_VARIABLE_C_NV = constant.Constant( 'GL_VARIABLE_C_NV', 0x8525 )
GL_VARIABLE_D_NV = constant.Constant( 'GL_VARIABLE_D_NV', 0x8526 )
GL_VARIABLE_E_NV = constant.Constant( 'GL_VARIABLE_E_NV', 0x8527 )
GL_VARIABLE_F_NV = constant.Constant( 'GL_VARIABLE_F_NV', 0x8528 )
GL_VARIABLE_G_NV = constant.Constant( 'GL_VARIABLE_G_NV', 0x8529 )
GL_CONSTANT_COLOR0_NV = constant.Constant( 'GL_CONSTANT_COLOR0_NV', 0x852A )
GL_CONSTANT_COLOR1_NV = constant.Constant( 'GL_CONSTANT_COLOR1_NV', 0x852B )
GL_PRIMARY_COLOR_NV = constant.Constant( 'GL_PRIMARY_COLOR_NV', 0x852C )
GL_SECONDARY_COLOR_NV = constant.Constant( 'GL_SECONDARY_COLOR_NV', 0x852D )
GL_SPARE0_NV = constant.Constant( 'GL_SPARE0_NV', 0x852E )
GL_SPARE1_NV = constant.Constant( 'GL_SPARE1_NV', 0x852F )
GL_DISCARD_NV = constant.Constant( 'GL_DISCARD_NV', 0x8530 )
GL_E_TIMES_F_NV = constant.Constant( 'GL_E_TIMES_F_NV', 0x8531 )
GL_SPARE0_PLUS_SECONDARY_COLOR_NV = constant.Constant( 'GL_SPARE0_PLUS_SECONDARY_COLOR_NV', 0x8532 )
GL_UNSIGNED_IDENTITY_NV = constant.Constant( 'GL_UNSIGNED_IDENTITY_NV', 0x8536 )
GL_UNSIGNED_INVERT_NV = constant.Constant( 'GL_UNSIGNED_INVERT_NV', 0x8537 )
GL_EXPAND_NORMAL_NV = constant.Constant( 'GL_EXPAND_NORMAL_NV', 0x8538 )
GL_EXPAND_NEGATE_NV = constant.Constant( 'GL_EXPAND_NEGATE_NV', 0x8539 )
GL_HALF_BIAS_NORMAL_NV = constant.Constant( 'GL_HALF_BIAS_NORMAL_NV', 0x853A )
GL_HALF_BIAS_NEGATE_NV = constant.Constant( 'GL_HALF_BIAS_NEGATE_NV', 0x853B )
GL_SIGNED_IDENTITY_NV = constant.Constant( 'GL_SIGNED_IDENTITY_NV', 0x853C )
GL_SIGNED_NEGATE_NV = constant.Constant( 'GL_SIGNED_NEGATE_NV', 0x853D )
GL_SCALE_BY_TWO_NV = constant.Constant( 'GL_SCALE_BY_TWO_NV', 0x853E )
GL_SCALE_BY_FOUR_NV = constant.Constant( 'GL_SCALE_BY_FOUR_NV', 0x853F )
GL_SCALE_BY_ONE_HALF_NV = constant.Constant( 'GL_SCALE_BY_ONE_HALF_NV', 0x8540 )
GL_BIAS_BY_NEGATIVE_ONE_HALF_NV = constant.Constant( 'GL_BIAS_BY_NEGATIVE_ONE_HALF_NV', 0x8541 )
GL_COMBINER_INPUT_NV = constant.Constant( 'GL_COMBINER_INPUT_NV', 0x8542 )
GL_COMBINER_MAPPING_NV = constant.Constant( 'GL_COMBINER_MAPPING_NV', 0x8543 )
GL_COMBINER_COMPONENT_USAGE_NV = constant.Constant( 'GL_COMBINER_COMPONENT_USAGE_NV', 0x8544 )
GL_COMBINER_AB_DOT_PRODUCT_NV = constant.Constant( 'GL_COMBINER_AB_DOT_PRODUCT_NV', 0x8545 )
GL_COMBINER_CD_DOT_PRODUCT_NV = constant.Constant( 'GL_COMBINER_CD_DOT_PRODUCT_NV', 0x8546 )
GL_COMBINER_MUX_SUM_NV = constant.Constant( 'GL_COMBINER_MUX_SUM_NV', 0x8547 )
GL_COMBINER_SCALE_NV = constant.Constant( 'GL_COMBINER_SCALE_NV', 0x8548 )
GL_COMBINER_BIAS_NV = constant.Constant( 'GL_COMBINER_BIAS_NV', 0x8549 )
GL_COMBINER_AB_OUTPUT_NV = constant.Constant( 'GL_COMBINER_AB_OUTPUT_NV', 0x854A )
GL_COMBINER_CD_OUTPUT_NV = constant.Constant( 'GL_COMBINER_CD_OUTPUT_NV', 0x854B )
GL_COMBINER_SUM_OUTPUT_NV = constant.Constant( 'GL_COMBINER_SUM_OUTPUT_NV', 0x854C )
GL_MAX_GENERAL_COMBINERS_NV = constant.Constant( 'GL_MAX_GENERAL_COMBINERS_NV', 0x854D )
glget.addGLGetConstant( GL_MAX_GENERAL_COMBINERS_NV, (1,) )
GL_NUM_GENERAL_COMBINERS_NV = constant.Constant( 'GL_NUM_GENERAL_COMBINERS_NV', 0x854E )
glget.addGLGetConstant( GL_NUM_GENERAL_COMBINERS_NV, (1,) )
GL_COLOR_SUM_CLAMP_NV = constant.Constant( 'GL_COLOR_SUM_CLAMP_NV', 0x854F )
glget.addGLGetConstant( GL_COLOR_SUM_CLAMP_NV, (1,) )
GL_COMBINER0_NV = constant.Constant( 'GL_COMBINER0_NV', 0x8550 )
GL_COMBINER1_NV = constant.Constant( 'GL_COMBINER1_NV', 0x8551 )
GL_COMBINER2_NV = constant.Constant( 'GL_COMBINER2_NV', 0x8552 )
GL_COMBINER3_NV = constant.Constant( 'GL_COMBINER3_NV', 0x8553 )
GL_COMBINER4_NV = constant.Constant( 'GL_COMBINER4_NV', 0x8554 )
GL_COMBINER5_NV = constant.Constant( 'GL_COMBINER5_NV', 0x8555 )
GL_COMBINER6_NV = constant.Constant( 'GL_COMBINER6_NV', 0x8556 )
GL_COMBINER7_NV = constant.Constant( 'GL_COMBINER7_NV', 0x8557 )
glCombinerParameterfvNV = platform.createExtensionFunction( 
'glCombinerParameterfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glCombinerParameterfvNV(GLenum(pname), GLfloatArray(params)) -> None',
argNames=('pname','params',),
deprecated=_DEPRECATED,
)

glCombinerParameterfNV = platform.createExtensionFunction( 
'glCombinerParameterfNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,),
doc='glCombinerParameterfNV(GLenum(pname), GLfloat(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)

glCombinerParameterivNV = platform.createExtensionFunction( 
'glCombinerParameterivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glCombinerParameterivNV(GLenum(pname), GLintArray(params)) -> None',
argNames=('pname','params',),
deprecated=_DEPRECATED,
)

glCombinerParameteriNV = platform.createExtensionFunction( 
'glCombinerParameteriNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,),
doc='glCombinerParameteriNV(GLenum(pname), GLint(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)

glCombinerInputNV = platform.createExtensionFunction( 
'glCombinerInputNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,),
doc='glCombinerInputNV(GLenum(stage), GLenum(portion), GLenum(variable), GLenum(input), GLenum(mapping), GLenum(componentUsage)) -> None',
argNames=('stage','portion','variable','input','mapping','componentUsage',),
deprecated=_DEPRECATED,
)

glCombinerOutputNV = platform.createExtensionFunction( 
'glCombinerOutputNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,constants.GLboolean,constants.GLboolean,constants.GLboolean,),
doc='glCombinerOutputNV(GLenum(stage), GLenum(portion), GLenum(abOutput), GLenum(cdOutput), GLenum(sumOutput), GLenum(scale), GLenum(bias), GLboolean(abDotProduct), GLboolean(cdDotProduct), GLboolean(muxSum)) -> None',
argNames=('stage','portion','abOutput','cdOutput','sumOutput','scale','bias','abDotProduct','cdDotProduct','muxSum',),
deprecated=_DEPRECATED,
)

glFinalCombinerInputNV = platform.createExtensionFunction( 
'glFinalCombinerInputNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,),
doc='glFinalCombinerInputNV(GLenum(variable), GLenum(input), GLenum(mapping), GLenum(componentUsage)) -> None',
argNames=('variable','input','mapping','componentUsage',),
deprecated=_DEPRECATED,
)

glGetCombinerInputParameterfvNV = platform.createExtensionFunction( 
'glGetCombinerInputParameterfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetCombinerInputParameterfvNV(GLenum(stage), GLenum(portion), GLenum(variable), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('stage','portion','variable','pname','params',),
deprecated=_DEPRECATED,
)

glGetCombinerInputParameterivNV = platform.createExtensionFunction( 
'glGetCombinerInputParameterivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetCombinerInputParameterivNV(GLenum(stage), GLenum(portion), GLenum(variable), GLenum(pname), GLintArray(params)) -> None',
argNames=('stage','portion','variable','pname','params',),
deprecated=_DEPRECATED,
)

glGetCombinerOutputParameterfvNV = platform.createExtensionFunction( 
'glGetCombinerOutputParameterfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetCombinerOutputParameterfvNV(GLenum(stage), GLenum(portion), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('stage','portion','pname','params',),
deprecated=_DEPRECATED,
)

glGetCombinerOutputParameterivNV = platform.createExtensionFunction( 
'glGetCombinerOutputParameterivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetCombinerOutputParameterivNV(GLenum(stage), GLenum(portion), GLenum(pname), GLintArray(params)) -> None',
argNames=('stage','portion','pname','params',),
deprecated=_DEPRECATED,
)

glGetFinalCombinerInputParameterfvNV = platform.createExtensionFunction( 
'glGetFinalCombinerInputParameterfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetFinalCombinerInputParameterfvNV(GLenum(variable), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('variable','pname','params',),
deprecated=_DEPRECATED,
)

glGetFinalCombinerInputParameterivNV = platform.createExtensionFunction( 
'glGetFinalCombinerInputParameterivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetFinalCombinerInputParameterivNV(GLenum(variable), GLenum(pname), GLintArray(params)) -> None',
argNames=('variable','pname','params',),
deprecated=_DEPRECATED,
)


def glInitRegisterCombinersNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.GL_422_pixels

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_GL_422_pixels'
_DEPRECATED = False
GL_422_EXT = constant.Constant( 'GL_422_EXT', 0x80CC )
GL_422_REV_EXT = constant.Constant( 'GL_422_REV_EXT', 0x80CD )
GL_422_AVERAGE_EXT = constant.Constant( 'GL_422_AVERAGE_EXT', 0x80CE )
GL_422_REV_AVERAGE_EXT = constant.Constant( 'GL_422_REV_AVERAGE_EXT', 0x80CF )


def glInitGl422PixelsEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension VERSION.GL_2_1_DEPRECATED

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_2_1'
_DEPRECATED = True
GL_CURRENT_RASTER_SECONDARY_COLOR = constant.Constant( 'GL_CURRENT_RASTER_SECONDARY_COLOR', 0x845F )
GL_SLUMINANCE_ALPHA = constant.Constant( 'GL_SLUMINANCE_ALPHA', 0x8C44 )
GL_SLUMINANCE8_ALPHA8 = constant.Constant( 'GL_SLUMINANCE8_ALPHA8', 0x8C45 )
GL_SLUMINANCE = constant.Constant( 'GL_SLUMINANCE', 0x8C46 )
GL_SLUMINANCE8 = constant.Constant( 'GL_SLUMINANCE8', 0x8C47 )
GL_COMPRESSED_SLUMINANCE = constant.Constant( 'GL_COMPRESSED_SLUMINANCE', 0x8C4A )
GL_COMPRESSED_SLUMINANCE_ALPHA = constant.Constant( 'GL_COMPRESSED_SLUMINANCE_ALPHA', 0x8C4B )

